function simsoar_base_run(thermalfields)

% simsoar_base_run(thermalfields)
%
% This function conducts the model base run as described in the paper
% 'Understanding soaring bird migration through interactions and 
% decisions at the individual level'
% by E.E. van Loon, J.Z. Shamoun-Baranes, W. Bouten, S.L. Davis,
% submitted in december 2009 to Journal of Theoretical Biology
%
% simsoar_base_run reads input data from the file 'simsoar_input.mat' 
% (which is generated by the function 'simsoar_generate_input.m') and 
% writes the outputs to the file 'simsoar_output.mat'.
% The data in the output file can be processed via the the function
% 'simsoar_process_output.m'. This function generates a.o. a few figures
% that summarize the model output.
%
% The data in the output file is organised via separate structured arrays 
% per combination of decision rule and thermal field. There are 10 
% decision rules in total and 200 thermal fields.
%
% The decision rules are indicated by the following names:
% 1) NnearT - non-social birds, selecting nearest thermal
% 2) NfarT - non-social birds, selecting furthest thermal
% 3) NnearD - non-social birds, selecting thermal nearest to destination
% 4) NdirD - non-social birds, selecting thermal nearest to destination direction
% 5) NrandT - non-social birds, selecting random thermal
% 6) SnearT - social birds, selecting nearest thermal
% 7) SfarT - social birds, selecting furthest thermal
% 8) SnearD - social birds, selecting thermal nearest to destination
% 9) SdirD - social birds, selecting thermal nearest to destination direction
% 10) SrandT - social birds, selecting random thermal
%
% And the Thermal fields are identified by adding a number to the
% array names. So the output files contain structured arrays with names
% like: 'NnearT1', 'NnearT2', ..., 'NnearT199', 'NnearT200', 'NfarT1',
% etc.
%
% An example:
%
% If you want to try this function, make sure that
% the data-file 'simsoar_input.mat' has been generated first by 
% the function 'simsoar_generate_input.m'
%
% Next, run simsoar_base_run only for a few thermal fields,
% to see how long it takes (a model run over one thermal field takes 
% typically 1 minute)
% If you run simsoar_base_run without input arguments, it simulates 
% over all 200 thermal fields in the file simsoar_input.mat).
% The size of the simsoar output-file for 200 thermal fields
% is a little bit less than 840 Mb
%
% simsoar_base_run([1:2])
%
%
%
%
% For questions, contact Emiel van Loon (vanloon@uva.nl)
% 
% Institute for Biodiversity and Ecosystem Dynamics
% University of Amsterdam
% Sciencepark 904
% 1098 XH Amsterdam
% The Netherlands

if nargin<1
  thermalfields = (1:200)';
end

% setting the state of the pseudo-random number generator
% to ensure reproducible results
rand('state',2421);

% labels, used for writing the output, later in the function
outputlbl = {'NnearT','NfarT','NnearD','NdirD','NrandT',...
    'SnearT','SfarT','SnearD','SdirD','SrandT'};

% load the boundary & bird input data,
% thermal data are loaded later
infile = 'simsoar_input.mat';
outfile = 'simsoar_output.mat';
load(infile,'Bound','Bird')

% create the file outfile, if it doen't exist
if exist(outfile,'file')==0
    save(outfile,'infile','thermalfields')
end

% calculating some values, for brevity only
nrBirds = length(Bird.ID);
TimeSteps = Bound.StartTime : Bound.TimeStep : Bound.EndTime;
nrTimeSteps = length(TimeSteps);
nrThermalFields = length(thermalfields);

% the initial values for bird are stored in another array,
% as we need to re-initialize the simulation for each
% new run (per thermalfield and decision rule)
initial = Bird;

% simulate per thermal field f,
% per decision rule dr, per time
% step k and per bird b
for f = 1:nrThermalFields
    
    tf = thermalfields(f);
    
    % load the appropriate thermal field and store it in the array 'Thermal'
    % clearing the thermal 'thermal_str' is  important as the function
    % simosar can evaluate many thermal fields (each of which can potentially
    % be quite large) consecutively and not clearing them would clog the memory
    thermal_str = ['Thermal' num2str(tf)];
    load(infile,thermal_str)
    eval( ['Thermal = ' thermal_str ';'])
    clear(thermal_str)
    
    for dr = 1:10
        
        disp( ['Decision rule ', num2str(dr), ', thermal field ', num2str(tf), '.'] );
        
        Bird = initial;

        % all birds use the same decision rule
        Bird.HypoWhich = ones(nrBirds,1)*dr;

        % the outputs are stored in arrays of the types 'single'
        % and 'unsigned 16 bits integers'
        outX = zeros(nrBirds,nrTimeSteps,'single');
        outY = zeros(nrBirds,nrTimeSteps,'single');
        outwhichThermal = zeros(nrBirds,nrTimeSteps,'uint16');
        
        % the letter k is used for time, the letter t is used
        % to indicate a thermal t in the simsoar (sub)routines
        for k = 1:nrTimeSteps
            
            % store the state of the arrays Bird and Thermal
            % in a second array so that the order of by which the
            % different birds are evaluated does not matter
            % note that only simsoar_sense considers the state of
            % other birds and thermals - so only that routine
            % uses these 'previous time step - arrays'
            BirdPrev = Bird;
            ThermalPrev = Thermal;
            
            for b = 1:nrBirds
                
                if ~BirdPrev.atDestination(b) && ~BirdPrev.onGround(b) ...
                        && ( BirdPrev.DepartureTime(b)<=k )
                    
                    if ~BirdPrev.inThermal(b) && ~BirdPrev.toTarget(b)
                        
                        % important: simsoar_sense takes the input from the
                        % arrays 'BirdPrev' and 'ThermalPrev', and
                        % stores the results into the appropriate
                        % places of the array 'Bird'
                        [ Bird.sDest(b), Bird.senseBirds{b}, Bird.senseThermals{b} ] = ...
                            simsoar_sense( BirdPrev, ThermalPrev, b );
                        
                        [ Bird ] = simsoar_think( Bird, b );
                        
                    end
                    
                    [Bird, Thermal] = simsoar_act( Bound, Bird, Thermal, b);
                    
                end
                
            end
            
            % storing some results per time step in the output array
            % the array Bird is overwritten in each timestep
            outX(:,k) = Bird.X;
            outY(:,k) = Bird.Y;
            outwhichThermal(:,k) = Bird.whichThermal;
            
        end

        % outputs for one run (the combination of decision rule and
        % thermal field) are packaged in the structured array 'outstor'
        outstor = struct([]);
        
        % the initial values of DestX and DestY are stored
        outstor(1).iDestX = single( initial.DestX );
        outstor(1).iDestY = single( initial.DestY );

        % all values of outX, outY and whichThermal are stored
        outstor(1).X = outX;
        outstor(1).Y = outY;
        outstor(1).whichThermal = outwhichThermal;
        
        % the values of FlightTime, atDestination, onGround and TimeLost
        % are stored for the last time step only
        outstor(1).FlightTime = single( Bird.FlightTime );
        outstor(1).atDestination = Bird.atDestination;
        outstor(1).onGround = Bird.onGround;
        outstor(1).TimeLost = single( Bird.TimeLost );

        % the output array is added to the output file
        outarray = [outputlbl{dr} num2str(tf)];
        eval( [ outarray '= outstor;'] )
        save(outfile,outarray,'-APPEND')
        clear(outarray)
        
    end
    
end


% save the vector 'thermalfields' to the output file,
% or add it to the existing vector 'thermalfields' if
% it already exists in the output file
thermalfields_added = thermalfields;
load(outfile,'thermalfields')
thermalfields = unique( [thermalfields; thermalfields_added] );
save(outfile,'thermalfields','-APPEND')

%%

function [sDest, senseBirds, senseThermals] = simsoar_sense(Bird,Thermal,b)

% simsoar_sense: evaluate the state of the environment, in particular the
% distance to all thermals with birds and without birds which are
% of interest to the current bird.
%
% Input: the arrays Bird and Thermal (containing all state variables
% and parameters), which represent the state at the previous time step;
% and the integer b, indicating the row number in the array Bird
% (the bird to be evaluated).
%
% Output: the logical scalar sDest, indicating whether the destination
% can be seen by the bird; the arrays senseBirds (p by 6, p = the
% number of thermals with birds in them which meet all criteria) and
% senseThermals (q by 6, q = the number of thermals which are meet all
% criteria). The three outputs are used by simsoar_think to choose a target.


sDest = false;
senseBirds = [];
senseThermals = [];

% The logical variables DestInView and DestInReach are evaluated
% to decide whether sDest has to be set to true, after which the bird will
% head straight to its destination
DestInView = ( Bird.ViewRadiusThermal(b) >= Bird.Dist2Dest(b) );
DestInReach = ( Bird.Z(b)* Bird.LiftToDragRatio(b) > Bird.Dist2Dest(b) );

if DestInView && DestInReach
    
    sDest = true;
    
else
    
    % The vectorised and nested construction below is chosen instead of
    % a simple loop over all thermals to increase the speed of the routine
    
    % Limit the search window to all thermals in a bounding-box, for
    % performance reasons
    fLimit = Bird.Z(b)* Bird.LiftToDragRatio(b);
    idx = find( ( abs(Bird.X(b)-Thermal.X) < fLimit ) & ( abs(Bird.Y(b)-Thermal.Y) < fLimit ) );
    
    
    if ~isempty(idx)
        
        % thermals that are within reach
        Dist2Thermal = sqrt( ( Bird.X(b) - Thermal.X(idx) ).^2 + ( Bird.Y(b) - Thermal.Y(idx) ).^2 );
        inReach = ( Dist2Thermal < fLimit ) & ( Dist2Thermal > Thermal.Radius(idx) );
        
        % the array distTtot is filled because this information is
        % required for the output arrays senseBirds and senseThermals
        distTtot = NaN( length(Thermal.X), 1 );
        distTtot(idx) = Dist2Thermal;
        
        % thermals that are in view window
        Dir2Thermal = atan2( Thermal.Y(idx) - Bird.Y(b), Thermal.X(idx) - Bird.X(b) ) * 180/pi;
        ccangle = abs( Bird.Dir2Dest(b) - Dir2Thermal );
        angleThermDest = min(360 - ccangle, ccangle);
        ThermalsInWindow = angleThermDest <= Bird.WindowSize(b)/2;
        
        % the array AngleTDtot is filled because this information is
        % required for the output arrays senseBirds and senseThermals
        angleTDtot = NaN( length(Thermal.X), 1 );
        angleTDtot(idx) = angleThermDest;
                                                                                                                                                                                                                                                                                                                                                                                                                                                   
        % thermals high enough
        minDist2Thermal = Dist2Thermal - Thermal.Radius(idx);
        ThermalsHighEnough = ( Bird.Z(b) - minDist2Thermal./ Bird.LiftToDragRatio(b) ) < Thermal.Height(idx) ;
        
        % the vector with indices, referring to the Thermal-arrays, is updated
        idx = idx(inReach & ThermalsInWindow & ThermalsHighEnough);
        
        if ~isempty(idx)
            
            % the indices of the thermals with birds in it that are considered by
            % bird b if it uses a 'social decision rule' (rules 6 to 10)
            sBidx = idx( ( Thermal.nrBirds(idx) > 0 ) & ( distTtot(idx) < Bird.ViewRadiusBird(b) ) );
            
            % the indices of the thermals (regardless whether they contain birds or not)
            % that are considered by bird b if it uses a 'non-social
            % decision rule' (rules 1 to 5)
            sTidx = idx( distTtot(idx) < Bird.ViewRadiusThermal(b) );
            
            senseBirds = [ Thermal.ID(sBidx), distTtot(sBidx), Thermal.Dist2Dest(sBidx), ...
                angleTDtot(sBidx), Thermal.X(sBidx), Thermal.Y(sBidx) ];
            senseThermals = [ Thermal.ID(sTidx), distTtot(sTidx), Thermal.Dist2Dest(sTidx) ...
                angleTDtot(sTidx), Thermal.X(sTidx), Thermal.Y(sTidx) ];
            
        end
    end
end




%%
function [ Bird ] = simsoar_think( Bird, b )

% simsoar_think: select a suitable target, based on the decision rule
% (named 'HypoWhich') and the output from simsoar_sense.
%
% Input: the array Bird (containing all state variables and parameters),
% which represent the state for bird b at the current time step;
% and the integer b, indicating the row number in the array Bird
% (the bird to be evaluated).
%
% Output: the array Bird in which the data for bird b has been updated.


DecisionRule = Bird.HypoWhich(b);
anyThermals = ~isempty(Bird.senseThermals{b});
anyBirds = ~isempty(Bird.senseBirds{b});

if Bird.sDest(b) == true
    % target coordinates <- destination coordinates
    targetX = Bird.DestX(b);
    targetY = Bird.DestY(b);
    Bird.toTarget(b) = true;
    
elseif ( DecisionRule == 1 || ( DecisionRule == 6 && ~anyBirds ) ) && anyThermals
    %   target coordinates <- coordinates of closest thermal (using
    %   senseThermals) 
    [midist, idx] = min( Bird.senseThermals{b}(:,2) );
    targetX = Bird.senseThermals{b}(idx,5);
    targetY = Bird.senseThermals{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseThermals{b}(idx,1);
    
elseif ( DecisionRule == 2 || ( DecisionRule == 7 && ~anyBirds ) )  && anyThermals
    %    target coordinates <- coordinates of furthest thermal (using
    %    senseThermals) 
    [madist, idx] = max( Bird.senseThermals{b}(:,2) );
    targetX = Bird.senseThermals{b}(idx,5);
    targetY = Bird.senseThermals{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseThermals{b}(idx,1);
    
elseif ( DecisionRule == 3 || ( DecisionRule == 8 && ~anyBirds ) ) && anyThermals
    %    target coordinates <- coordinates of thermal closest to
    %    destination (using senseThermals) 
    [midest, idx] = min( Bird.senseThermals{b}(:,3) );
    targetX = Bird.senseThermals{b}(idx,5);
    targetY = Bird.senseThermals{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseThermals{b}(idx,1);
    
elseif ( DecisionRule == 4 || ( DecisionRule == 9 && ~anyBirds ) ) && anyThermals
    %    target coordinates <- coordinates of thermal closest to
    %    target-direction (using senseThermals)
    [midest, idx] = min( Bird.senseThermals{b}(:,4) );
    targetX = Bird.senseThermals{b}(idx,5);
    targetY = Bird.senseThermals{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseThermals{b}(idx,1);
    
elseif ( DecisionRule == 5 || ( DecisionRule == 10 && ~anyBirds ) ) && anyThermals
    idx = ceil( rand * size(Bird.senseThermals{b},1) );
    %    target coordinates <- coordinates of random thermal from view
    %    window 
    targetX = Bird.senseThermals{b}(idx,5);
    targetY = Bird.senseThermals{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseThermals{b}(idx,1);
    
elseif DecisionRule == 6 && anyBirds
    %    target coordinates <- coordinates of closest thermal with birds
    %    (using senseBirds) 
    [midist, idx] = min( Bird.senseBirds{b}(:,2) );
    targetX = Bird.senseBirds{b}(idx,5);
    targetY = Bird.senseBirds{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseBirds{b}(idx,1);
    
elseif DecisionRule == 7 && anyBirds
    %    target coordinates <- coordinates of furthest thermal with birds
    %    (using senseBirds) 
    [madist, idx] = max( Bird.senseBirds{b}(:,2) );
    targetX = Bird.senseBirds{b}(idx,5);
    targetY = Bird.senseBirds{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseBirds{b}(idx,1);
    
elseif DecisionRule == 8 && anyBirds
    %    target coordinates <- coordinates of thermal closest to
    %    destination (using senseBirds)
    [midest, idx] = min( Bird.senseBirds{b}(:,3) );
    targetX = Bird.senseBirds{b}(idx,5);
    targetY = Bird.senseBirds{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseBirds{b}(idx,1);
    
elseif DecisionRule == 9 && anyBirds
    %    target coordinates <- coordinates of thermal closest to
    %    target-direction (using senseBirds)
    [midest, idx] = min( Bird.senseBirds{b}(:,4) );
    targetX = Bird.senseBirds{b}(idx,5);
    targetY = Bird.senseBirds{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseBirds{b}(idx,1);
    
elseif DecisionRule == 10 && anyBirds
    %    target coordinates <- coordinates of random thermal with birds
    %    from view window (using senseBirds)
    idx = ceil( rand * size(Bird.senseBirds{b},1) );
    targetX = Bird.senseBirds{b}(idx,5);
    targetY = Bird.senseBirds{b}(idx,6);
    Bird.toTarget(b) = true;
    Bird.whichThermal(b) = Bird.senseBirds{b}(idx,1);
    
else
    % there are no thermals and no thermals with birds seen, so by lack
    % of any other potential target the bird flies to destination
    % target coordinates <- destination coordinates
    targetX = Bird.DestX(b);
    targetY = Bird.DestY(b);
    Bird.toTarget(b) = false;
    Bird.whichThermal(b) = NaN;
end

Bird.TargetX(b) = targetX;
Bird.TargetY(b) = targetY;
Bird.Dir2Target(b) = atan2( targetY - Bird.Y(b), targetX - Bird.X(b) ) * 180/pi;


%%
function [Bird, Thermal] = simsoar_act(Bound,Bird,Thermal,b)

% simsoar_act: move the bird up in a thermal or glide towards it's target
%
% Input: the arrays Bound, Bird and Thermal (containing all state variables
% and parameters), and the integer b, indicating the row number in the
% array Bird (the bird to be evaluated).
%
% Output: the array Bird in which the data for bird b has been updated,
% and the array Thermal in which the information is updated for thermal t
% if bird b has entered or left that Thermal.


dt = Bound.TimeStep;

% if a bird is climbing in a thermal
if Bird.inThermal(b)   
    
    %   In this version of Simsoar, the thermals are static
    %   throughout the simulation, so that Thermal.ID(t) = t (the rownr
    %   in the array Thermal is the same as the id of that thermal)
    %   This property is used to make simsoar slightly faster.
    %   The more general statement would be:
    %   t =  ( Thermal.ID == Bird.whichThermal(b) );
    t = Bird.whichThermal(b);
    
    % bird climbs in thermal, with a speed proportional to
    % the thermal lift index
    lidx = Thermal.Lidx(t);
    height = Thermal.Height(t);
    Bird.dZ(b) = dt * Bird.Lidx2Speed( b ) * lidx;
    Bird.Z(b) = Bird.Z( b ) + Bird.dZ( b );
    
    % If the top of the thermal is reached, the bird leaves the thermal
    % and starts to search for a new target. It's default target is the
    % destination. At the top of the thermal, the value for
    % Thermal.nrBirds(t) is updated as well.
    % Note that while climbing Dist2Dest, DestX, DestY and Dir2Dest and
    % toTarget remained unchanged so that the values set when entering the
    % thermal are still in use.
    if Bird.Z(b) >= height

        Bird.inThermal(b) = false;
        Thermal.nrBirds(t) = Thermal.nrBirds(t)-1;
        Bird.whichThermal(b) = NaN;

% It may be desirable to move the the bird back to the top of the termal
% once it has climbed beyond that top during the last time step. 
% In that case the trajectories of the different birds would coincide 
% more than the current algorithm without the correction. 
% When moving the bird back to the top of a thermal, the following commands
% would be used:
%       Bird.TimeLost(b) = Bird.TimeLost(b) + (Bird.Z(b)-height) / ( Bird.Lidx2Speed( b ) * lidx );
%       Bird.Z(b) = height;
        
    end
    
else  % bird is flying towards a thermal or destination
    
    Bird.dZ(b) = - ( Bird.Velocity(b)/Bird.LiftToDragRatio(b) ) * dt;
    Bird.Z(b) = Bird.Z(b) + Bird.dZ(b);
    
    BirdprevX = Bird.X(b);
    BirdprevY = Bird.Y(b);
    
    dX = cos ( Bird.Dir2Target(b)*pi/180 );
    dY = sin ( Bird.Dir2Target(b)*pi/180 );
    Bird.X(b) = Bird.X(b) + dX * Bird.Velocity(b) * dt;
    Bird.Y(b) = Bird.Y(b) + dY * Bird.Velocity(b) * dt;
    
    if Bird.Z(b)<=0
        
        Bird.onGround(b) = true;
        Bird.toTarget(b) = false;
        
    % a bird will always first see the destination before it is
    % entering the destination polygon, the outer-if condition
    % is included so that 'lastDist' and 'DistInDest'
    % do not have to be evaluated too frequently
    elseif Bird.sDest(b)
        
        lastDist = sqrt( (Bird.X(b) - BirdprevX)^2 + (Bird.Y(b) - BirdprevY)^2 );
        DistInDest = lastDist - Bird.Dist2Dest(b);

        if DistInDest>0
            Bird.atDestination(b) = true;
            Bird.toTarget(b) = false;
            
            Bird.TimeLost(b) = Bird.TimeLost(b) + DistInDest/Bird.Velocity(b);
        end
        
    % if Bird.toTarget(b) is true it means that the bird will
    % sooner or later enter a thermal, also (since a simsoar-bird
    % senses its environment perfectly) it will never enter a
    % thermal if it didn't dectect one ( Bird.toTarget(b) = false )
    elseif Bird.toTarget(b)

        t = Bird.whichThermal(b);
        % more general: t =  Thermal.ID == Bird.whichThermal(b);
        
        DistBird2Thermal = sqrt( ( Bird.X(b) - Thermal.X(t) )^2 + ( Bird.Y(b) - Thermal.Y(t) )^2 );
        % Note: previously the following construction was used
        %   [ DistBird2Thermal, t ] = min( sqrt( (Bird.X(b) - Thermal.X).^2 + (Bird.Y(b) - Thermal.Y).^2 ) );
        % but that was too costly: it calculated the distance to all the thermals in the field
        
        if ( DistBird2Thermal <= Thermal.Radius(t) ) &&  ( Bird.Z(b) < Thermal.Height(t) )
            
            Thermal.nrBirds(t) = Thermal.nrBirds(t)+1;
            
            Bird.inThermal(b) = true;
            Bird.toTarget(b) = false;

% It can be desirable to move the the bird upon entering a thermal
% instantaneously to to the center of that thermal.
% In that case the trajectories would coincide more and would look
% different when visualised (the birds would all rise at the same point
% in thermals). The artificial time-gain due to this displacement would 
% have to be calculated as well. When moving to thermal center, the 
% follwing commands would be added:
%
%             Bird.X(b) = Thermal.X(t);
%             Bird.Y(b) = Thermal.Y(t);
%                       
%            TimeGain_hor_displacement = DistBird2Thermal/Bird.Velocity(b);
%            TimeGain_no_height_loss = DistBird2Thermal / ...
%                ( Bird.LiftToDragRatio(b)* Bird.Lidx2Speed( b ) * Thermal.Lidx(t) );
%            Bird.TimeLost(b) = Bird.TimeLost(b) - TimeGain_hor_displacement - TimeGain_no_height_loss;
            
        end
        
    end
    
    % The general way to calculate the distance to the destination is
    % by using the generic function 'distPoint2Poly', but in the
    % simulations used here, using a simple destination geometry,
    % it suffices to take the difference between the minimum y-coordinate
    % of the destination polygon and the current y-cooridinate.
    % It saves a bit of calculation time.
    %    [Bird.Dist2Dest(b), Bird.DestX(b), Bird.DestY(b)] = ...
    %            distPoint2Poly( [Bird.X(b), Bird.Y(b)], Bound.DestPoly );
    Dxmi = min(Bound.DestPoly(:,1));
    Dxma = max(Bound.DestPoly(:,1));
    Bird.DestY(b) = max( Bird.Y(b), min(Bound.DestPoly(:,2)) );
    Bird.DestX(b) = min( Dxma, max( Dxmi, Bird.X(b) ) );
    Bird.Dist2Dest(b) = sqrt( ( Bird.X(b)-Bird.DestX(b) )^2 + ( Bird.Y(b)-Bird.DestY(b) )^2 );
    Bird.Dir2Dest(b) = atan2( Bird.DestY(b) - Bird.Y(b), Bird.DestX(b) - Bird.X(b) ) * 180/pi;
    
    Bird.FlightTime(b) = Bird.FlightTime(b) + dt;
    
end
