function simsoar_generate_input( inputFileName )

% simsoar_generate_input(inputFileName)
%
% This function generates the input data used in the paper
% 'Understanding soaring bird migration through interactions and 
% decisions at the individual level'
% by E.E. van Loon, J.Z. Shamoun-Baranes, W. Bouten, S.L. Davis,
% submitted in december 2009 to Journal of Theoretical Biology
%
% A domain of 100 x 200 km (20000 km^2) is used.
% The domain could be defined slightly different as well:
% Birds are departing from and arriving at a 1 x 90 km strip
% hence there is  fly-domain of 20000 - 180 = 19820 km^2 
%
% The parameters:
%
% domain: 100 x 200
% departure strip: 80 x 1
% destination strip: 80 x 1
% 200 thermal fields
% 
% thermal density			0.1		nr km-2
% thermal height			1000	m
% thermal diameter			400		m
% thermal lift (tl)			3		m s-1
% bird density				0.01	nr km-2 
% vg						12		m s-1
% lift to drag ratio (ldr) 	15		m m-1
% climbing efficiency (ce)	0.8		-
% view angle 				120		degrees
% thermal detection limit	4000	m
% bird detection limit		10000	m
%
%
%
% For questions, contact Emiel van Loon (vanloon@uva.nl)
% 
% Institute for Biodiversity and Ecosystem Dynamics
% University of Amsterdam
% Sciencepark 904
% 1098 XH Amsterdam
% The Netherlands
% tel. +31 20 5257448 or +31 20 525 6635


if nargin<1
  inputFileName = 'simsoar_input.mat';
end


thermaldens = 0.1;
birddens = 0.01;
runnrs = 1:200;

hypowhich = 1;
nrthermals = round(thermaldens*20000);
nrbirds = round(birddens*20000);

rand('state',564);
randn('state',9173);
rndstates = randperm(10000);
rndstates = rndstates(1:1000);

% make Bounds

Bound.StartTime = 0;                        % seconds
Bound.EndTime = 60*(60*8+20);               % 8 hours and 20 minutes, expressed in seconds
Bound.TimeStep = 60;                        % seconds
Bound.RestStop = 0;                         % continue till 8 hours, regardsless whether there are still birds in the domain or not
Bound.DomainPoly = 1000 * [0 0; 0 200; 100 200; 100 0; 0 0];             % 100 x 100 km block
Bound.DestPoly = 1000 * [10 199; 10 200; 90 200; 90 199; 10 199];        % strip of 1 km, 80 km wide

% make Birds

BirdPar.Number                  = nrbirds;    
BirdPar.HypoWhich               = hypowhich;
BirdPar.HypoWhen                = 0;
BirdPar.Velocity.min            = 13;
BirdPar.Velocity.max            = 13;
BirdPar.ViewRadiusThermal.min   = 4000;   % m
BirdPar.ViewRadiusThermal.max   = 4000;   % m
BirdPar.ViewRadiusBird.min      = 10000;   % m
BirdPar.ViewRadiusBird.max      = 10000;   % m
BirdPar.LiftToDragRatio.min     = 15;
BirdPar.LiftToDragRatio.max     = 15;
BirdPar.WindowSize.min          = 120;
BirdPar.WindowSize.max          = 120;
BirdPar.Lidx2Speed.min          = 0.8;
BirdPar.Lidx2Speed.max          = 0.8;
BirdPar.DestX.min               = max( Bound.DomainPoly(:,1) );
BirdPar.DestX.max               = max( Bound.DomainPoly(:,1) );
BirdPar.DestY.min               = max( Bound.DomainPoly(:,2) );
BirdPar.DestY.max               = max( Bound.DomainPoly(:,2) );
BirdPar.StartPoly       = 1000 * [10 0; 10 1; 90 1; 90 0; 10 0];         % strip of 1 km, 80 km wide
BirdPar.DestPoly        = Bound.DestPoly;
BirdPar.StartZ.min              = 1000;
BirdPar.StartZ.max              = 1000;
BirdPar.RandState               = rndstates(1);
BirdPar.DepartureTime.min       = 1;     % model time step when the bird takes off
BirdPar.DepartureTime.max       = 1;

[Bird] = mkBird( BirdPar, nrthermals);

for i = runnrs

    disp( ['Generating thermal field ' num2str(i)] ) 
    
    ThermPar.Number       =  nrthermals;   %
    ThermPar.Lidx.min     =    3;   % m/s
    ThermPar.Lidx.max     =    3;   % m/s
    ThermPar.Height.min   = 1000;   % m
    ThermPar.Height.max   = 1000;   % m
    ThermPar.Radius.min   =  400;   % m
    ThermPar.Radius.max   =  400;   % m
    ThermPar.StartPoly    =  1000 * [0 1; 0 199; 100 199; 100 1; 0 1]; %
    ThermPar.RandState    =  rndstates(i);    %

    eval(['Thermal' num2str(i) ' = mkTherm( ThermPar, Bound );' ]);

end


% Note that you are fine if:
%
% ( Thermal.Radius.max  <  Bound.TimeStep * Bird.Velocity.min ) && ...
%     ( 2 * Thermal.Radius.min  >= Bound.TimeStep * Bird.Velocity.max) ;
%
% Otherwise, the if-loop below wil autmatically adjust
% your timestep so that it falls between these bounds.
% And if the parameter values are such that the above comparison returns
% a 'FALSE' (regardless the value you choose for Bound.TimeStep,
% you will receive a warning.

% if ( max(Thermal.Radius) >= Bound.TimeStep * min(Bird.Velocity) ) || ...
%       ( 2 * min(Thermal.Radius) < Bound.TimeStep * max(Bird.Velocity) )
%
%   mintimestep = max(Thermal.Radius) / min(Bird.Velocity);
%   maxtimestep = 2 * min(Thermal.Radius) / max(Bird.Velocity);
%
%   if mintimestep >= maxtimestep
%       disp('The selection of your range for thermal radius and bird velocity');
%       disp('is such that you may overshoot thermals');
%       Bound.TimeStep = maxtimestep;
%   end
%
%   Bound.TimeStep = (maxtimestep + mintimestep) / 2;
%
% end
%

% save the input values generated now
if exist(inputFileName,'file')
    save(inputFileName,'Bound','Bird','Thermal*', '-APPEND')
else
    save(inputFileName,'Bound','Bird','Thermal*')
end

%%

function [Bird] = mkBird( BirdPar, Thermal )
%Generates inital bird data on the basis of parameter file. 
%  In addition the number of thermals with which this bird file
%  is to be combined can be specified.
%
%  Bird      = structured array with initial bird states and parameter values
%  BirdPar   = structured array with parameters to generate the Bird
%              structure
%  Thermal   = structured array with thermal location and parameters,
%              or a scalar indicating the number of thermals 
%              (optional, default = 10)
%
%
% The following example makes clear which fields have to be present
% in the structured array BirdPar, and provides some typical values
% for the several parameters.
% 
% BirdPar.Number                  = 10;
% BirdPar.HypoWhich               = 3;
% BirdPar.HypoWhen                = 1;
% BirdPar.Velocity.min            = 10;
% BirdPar.Velocity.max            = 10;
% BirdPar.ViewRadiusThermal.min   = 300;    % m
% BirdPar.ViewRadiusThermal.max   = 300;    % m
% BirdPar.ViewRadiusBird.min      = 1500;   % m
% BirdPar.ViewRadiusBird.max      = 1500;   % m
% BirdPar.LiftToDragRatio.min     = 5;
% BirdPar.LiftToDragRatio.max     = 5;
% BirdPar.WindowSize.min          = 20;
% BirdPar.WindowSize.max          = 20;
% BirdPar.Lidx2Speed.min          = 0.8;
% BirdPar.Lidx2Speed.max          = 0.8;
% BirdPar.DestX.min               = 50000;
% BirdPar.DestX.max               = 50000;
% BirdPar.DestY.min               = 20000;
% BirdPar.DestY.max               = 20000;
% BirdPar.StartPoly               = [0 0; 1000 0; 1000 1000; 0 1000; 0 0]; 
% BirdPar.DestPoly                = 1000* [10 10; 9 10; 9 9; 10 9; 10 10]; 
% BirdPar.StartZ.min              = 500;
% BirdPar.StartZ.max              = 1000;
% BirdPar.RandState               = 352;   
% BirdPar.DepartureTime.min       = 1;     % model time step when the bird takes off
% BirdPar.DepartureTime.max       = 1;
%
%
% [ Bird ] = mkBird( BirdPar, 5 );
% 
% plot3(Bird.X, Bird.Y, Bird.Z, 'ro'); grid on;
%
% See also mkBound, mkTherm, mmkBird, mmkBound, mmkTherm 

% Emiel van Loon <vanloon@uva.nl>
% December 2009

rand('state',BirdPar.RandState);
randn('state',BirdPar.RandState);

nrb = BirdPar.Number;

if nargin<2
    Thermal = 5;
end

if isstruct(Thermal)
    nrt = length(Thermal.ID);
else
    nrt = Thermal;
end    

Bird.ID = (1 : nrb )';
Bird.HypoWhich = BirdPar.HypoWhich * ones(nrb,1);
[Bird.X, Bird.Y] = rndPointInPoly( BirdPar.StartPoly, nrb );
Bird.Z = rand(nrb,1) * ( BirdPar.StartZ.max- BirdPar.StartZ.min ) + BirdPar.StartZ.min;
[Bird.Dist2Dest, Bird.DestX, Bird.DestY] = distPoint2Poly( [Bird.X, Bird.Y], BirdPar.DestPoly);
Bird.Dir2Dest = atan2( Bird.DestY - Bird.Y, Bird.DestX - Bird.X ) * 180/pi;
Bird.Velocity = BirdPar.Velocity.min * ones(nrb,1)  + rand(nrb,1) * ( BirdPar.Velocity.max - BirdPar.Velocity.min );
Bird.ViewRadiusThermal = BirdPar.ViewRadiusThermal.min * ones(nrb,1) + rand(nrb,1) * ( BirdPar.ViewRadiusThermal.max - BirdPar.ViewRadiusThermal.min );
Bird.ViewRadiusBird = BirdPar.ViewRadiusBird.min * ones(nrb,1) + rand(nrb,1) * ( BirdPar.ViewRadiusBird.max - BirdPar.ViewRadiusBird.min );
Bird.LiftToDragRatio = BirdPar.LiftToDragRatio.min * ones(nrb,1) + rand(nrb,1) * ( BirdPar.LiftToDragRatio.max - BirdPar.LiftToDragRatio.min );
Bird.WindowSize = BirdPar.WindowSize.min * ones(nrb,1) + rand(nrb,1) * ( BirdPar.WindowSize.max - BirdPar.WindowSize.min ); 
Bird.Lidx2Speed = BirdPar.Lidx2Speed.min * ones(nrb,1) + rand(nrb,1) * ( BirdPar.Lidx2Speed.max - BirdPar.Lidx2Speed.min ); 
Bird.dZ = zeros(nrb,1);
Bird.FlightTime     = zeros(nrb,1);
Bird.TimeLost       = zeros(nrb,1);

Bird.sDest          = false(nrb,1);
Bird.atDestination  = false(nrb,1);
Bird.onGround       = false(nrb,1);
Bird.inThermal      = false(nrb,1);
Bird.toTarget       = false(nrb,1);
Bird.whichThermal   = nan(nrb,1);
Bird.TargetX        = nan(nrb,1);
Bird.TargetY        = nan(nrb,1);

Bird.senseBirds     = cell(nrb,1);
Bird.senseThermals  = cell(nrb,1);

Bird.DepartureTime = round( rand(nrb,1) * (BirdPar.DepartureTime.max - BirdPar.DepartureTime.min) + BirdPar.DepartureTime.min );

%%

function [Therm] = mkTherm( ThermPar, Bound, plotit )

%  Generates thermal data on the basis of a parameter file.
%  The desired number of thermals are generated at random locations 
%  within a specified polygon such that the thermals do not overlap.
%
%  Therm     = structured array with thermal parameter values
%  ThermPar  = structured array with parameters to generate the Therm
%              structure
%  Bound     = structured array with boundary conditions
%  pltit     = flag to ask for a plot of the thermal field
%              (optional, default = 0)
%
%
% The following example makes clear which fields have to be present
% in the structured array ThermPar, and provides some typical values
% for the several parameters.
%
% ThermPar.Number       =   30;   % 
% ThermPar.Lidx.min     =    2;   % m/s
% ThermPar.Lidx.max     =    4;   % m/s
% ThermPar.Height.min   =  500;   % m
% ThermPar.Height.max   = 1000;   % m
% ThermPar.Radius.min   =  100;   % m
% ThermPar.Radius.max   =  300;   % m
% ThermPar.StartPoly    = [0 0; 10000 0; 10000 10000; 0 10000; 0 0];   %
% ThermPar.RandState    = 342;    %
%
% [Therm] = mkTherm_iter( ThermPar, 1 )
%
% See also mkBird, mkBound, mmkBird, mmkBound, mmkTherm 

% Emiel van Loon <vanloon@uva.nl>
% December 2009


if nargin<3 || isempty(plotit) || plotit==0 || plotit(1)=='f'
    plotit = false;
else
    plotit = true;
end

rand('state',ThermPar.RandState);
randn('state',ThermPar.RandState);

nrt = ThermPar.Number;

Therm.ID = (1 : nrt )';
Therm.Height = ThermPar.Height.min * ones(nrt,1) + rand(nrt,1) * ( ThermPar.Height.max - ThermPar.Height.min );
Therm.Lidx = rand(nrt,1) * ( ThermPar.Lidx.max - ThermPar.Lidx.min ) + ThermPar.Lidx.min * ones(nrt,1);

Therm.Radius = rand( nrt, 1 ) * ( ThermPar.Radius.max - ThermPar.Radius.min ) + ThermPar.Radius.min * ones( nrt, 1 );
Therm.X = NaN(nrt,1);
Therm.Y = NaN(nrt,1);
[Therm.X(1), Therm.Y(1)] = rndPointInPoly( ThermPar.StartPoly, 1 );
Therm.nrBirds = zeros(nrt,1);

finishTherm = 1;

while finishTherm < nrt;

    Radius2 = Therm.Radius(1:finishTherm) + Therm.Radius(finishTherm+1);
    [Tx,Ty] = rndPointInPoly( ThermPar.StartPoly, 1 );

    no_overlap = isempty( find( Radius2 > ... 
         sqrt( (Therm.X(1:finishTherm) - Tx).^2 + (Therm.Y(1:finishTherm) - Ty).^2 ) , 1) );
    
    if no_overlap
        finishTherm = finishTherm+1;
        Therm.X( finishTherm ) = Tx;
        Therm.Y( finishTherm ) = Ty;
    end
    
end

Therm.Dist2Dest = distPoint2Poly( [Therm.X, Therm.Y], Bound.DestPoly );

%%

function [ Tdist, TPpx, TPpy ] = distPoint2Poly(P,Poly)

%[ dist,Ppx,Ppy ] = distPoint2Poly(P,Poly)
%
% calculates the shortest distance dist and point of intersection
% (Ppx,Ppy) from point P to the polygon specified by the (n,2) matrix
% P can also be a (m,2) matrix with a set of points.
%
% e.g.
%
% % a 'normal' case
%
% Poly = [0 ,0; 2 0; 3 2; 2 3; 0 3; 0 0];
% P = [3,4];
% [d,Ppx,Ppy] = distPoint2Poly(P,Poly);
% figure,
% plot(Poly(:,1),Poly(:,2),'b-',P(1),P(2),'ro',Ppx,Ppy,'r+',...
%      [P(1) Ppx], [P(2) Ppy], 'r:' );
% axis square
% axis([-1 5 -1 5])
%
% hold on
% P = [3,3];
% [d,Ppx,Ppy] = distPoint2Poly(P,Poly);
% plot(P(1),P(2),'co',Ppx,Ppy,'c+',[P(1) Ppx], [P(2) Ppy],'c:');
%
% % and a concave polygon
%
% Poly = [0 ,0; 2 0; 1 1; .5 1; 0 3; 0 0];
% P = [3,3];
% [d,Ppx,Ppy] = distPoint2Poly(P,Poly);
% figure,
% plot(Poly(:,1),Poly(:,2),'b-',P(1),P(2),'ro',Ppx,Ppy,'r+',...
%      [P(1) Ppx], [P(2) Ppy], 'r:'  );
% axis square
% axis([-1 4 -1 4])
%

% Emiel van Loon <vanloon@uva.nl>
% February 2007


% transpose the poygon if it has a wrong orientation
[r,c]=size(Poly);
if r==2
    Poly = Poly';
end

% make a closed polygon (i.e. first and last point are the same)
% because this routine deals with polygons where
% the start and endpoints are repeated
if sum( Poly(1,:) == Poly(end,:) ) ~= 2
    Poly = [ Poly; Poly(1,:)];
end
nrsides = size(Poly,1)-1;

% transpose the set of points if it has a wrong orientation
[r,c]=size(P);
if r==2 && c>2
    P = P';
end
nrpt = size(P,1);

% create empty output vectors
Tdist = zeros(nrpt,1);
TPpx = zeros(nrpt,1);
TPpy = zeros(nrpt,1);

for i = 1:nrpt

    % handle case when point is inside or on vertices of polygon: distance is zero

    Sdist = zeros(nrsides,1);
    SPpx = zeros(nrsides,1);
    SPpy = zeros(nrsides,1);
    
    if ~inpolygon( P(i,1), P(i,2), Poly(:,1), Poly(:,2) );

        %         dist2nodes = sqrt( (Poly(:,1) - P(i,1)).^2 + (Poly(:,2) - P(i,2)).^2 );
        %         [ sorted, sort_idx ] = sort(dist2nodes);
        %         nearest_side = Poly( sort_idx( [1, 2] ), : );
        for j = 1:nrsides
            [ Sdist(j), SPpx(j), SPpy(j) ] = distPoint2Line( P(i,:), Poly(j,:), Poly(j+1,:) );
        end
        [dist,idx] = min(Sdist);
        Ppx = SPpx(idx);
        Ppy = SPpy(idx);

    else  % the location is on the edge of inside the polygon

        dist = 0;
        Ppx = NaN;
        Ppy = NaN;

    end

    Tdist(i) = dist;
    TPpx(i) = Ppx;
    TPpy(i) = Ppy;

end

%%

function [ dist, Ppx, Ppy ] = distPoint2Line(P,A,B)

%[dist,Ppx,Ppy] = distPoint2Line(P,A,B)
%
% calculates the shortest distance (dist) and point of intersection
% (Ppx,Ppy) from point P to the linepiece between A and B
%
% e.g.
%
% A = [1,1];
% B = [3,3];
% P = [2,3];
% [d,Ppx,Ppy] = distPoint2Line(P,A,B)
% figure,
% plot(A(1),A(2),'go',B(1),B(2),'go',[A(1) B(1)],...
%      [A(2) B(2)],'b-',P(1),P(2),'ro',Ppx,Ppy,'r+',...
%      [P(1) Ppx], [P(2) Ppy], 'r:' )
%
% P = [5,6];
% [d,Ppx,Ppy] = distPoint2Line(P,A,B)
% figure,
% plot(A(1),A(2),'go',B(1),B(2),'go',[A(1) B(1)],...
%      [A(2) B(2)],'b-',P(1),P(2),'ro',Ppx,Ppy,'r+',...
%      [P(1) Ppx], [P(2) Ppy], 'r:' )
%
% P = [0,1];
% [d,Ppx,Ppy] = distPoint2Line(P,A,B)
% figure,
% plot(A(1),A(2),'go',B(1),B(2),'go',[A(1) B(1)],...
%      [A(2) B(2)],'b-',P(1),P(2),'ro',Ppx,Ppy,'r+',...
%      [P(1) Ppx], [P(2) Ppy], 'r:' )


% Emiel van Loon <vanloon@uva.nl>
% February 2007

% input handling and renaming to make the following statements shorter

A = A(:);
B = B(:);
P = P(:);

bx = B(1);
by = B(2);
ax = A(1);
ay = A(2);
px = P(1);
py = P(2);

% calculate projection of point P on line AB

D = [ bx-ax  by-ay; ay-by  bx-ax ];
m = [ px*(bx - ax) + py*(by-ay) ; ay*(bx-ax) - ax*(by-ay) ];
Pp = D\m;


% calculate all reqruied lengths

dist = norm(P-Pp);

ABlen = norm(B-A);
APplen = norm(Pp-A);
BPplen = norm(Pp-B);


% deal with the case that P is 'beyond' A or B

if APplen >= ABlen && APplen > BPplen
    Pp = B;
    dist = norm(P-Pp);
elseif APplen >= ABlen && APplen < BPplen
    Pp = A;
    dist = norm(P-Pp);
elseif BPplen >= ABlen && BPplen > APplen
    Pp = A;
    dist = norm(P-Pp);
elseif BPplen >= ABlen && BPplen < APplen
    Pp = B;
    dist = norm(P-Pp);
end

% so: if APplen < ABlen && BPplen < ABlen
% Pp is between A and B, and nothing needs
% to be done

Ppx = Pp(1);
Ppy = Pp(2);

%%

function [RNDX,RNDY] = rndPointInPoly(poly,nrpoint)
%
% rndPointInPoly
%
% [x,y] = rndPointInPoly(poly,nrpoint)
%
% Function to generate uniformaly distributed random points in one or more
% polygons. The vertices of the polygons are given in the two columns of poly
% the first column of poly contains the x-coordinates, the second column the y-coordinates
% each polygon is separated by two NaN's in the matrix poly (the same
% property as used in the matlab plot function).
%
%
% % e.g.
%
% poly = [0 0 1 2 3 3 2 0 NaN 6 7 8 8 7 7 6; 0 1 1 2 2 1 1 0 NaN 3 4 4 5 4 3 3]';
% [rx,ry]=rndPointInPoly(poly,10); 
% plot(poly(:,1),poly(:,2),'b-',rx,ry,'r+')


% count nr of polygons
polysplit = [ 0, find( isnan( poly(:,1) ) ), length( poly(:,1) )+1 ];
nrpoly = sum( isnan(poly(:,1)) ) + 1;
nrRequiredPerPoly = ceil(nrpoint/nrpoly);

RNDX = [];
RNDY = [];

for i = 1:length(polysplit)-1

    xpoly = poly( polysplit(i)+1 : polysplit(i+1)-1 , 1 );
    ypoly = poly( polysplit(i)+1 : polysplit(i+1)-1 , 2 );
    [max_x] = max( xpoly );
    [min_x] = min( xpoly );

    [max_y] = max( ypoly );
    [min_y] = min( ypoly );

    rndx = [];
    rndy = [];
    nrinpoly = 0;

    while nrinpoly < nrRequiredPerPoly

        rndx_add = rand(nrpoint,1) * (max_x - min_x) + min_x ;
        rndy_add = rand(nrpoint,1) * (max_y - min_y) + min_y ;
        isinpoly = inpolygon( rndx_add, rndy_add, xpoly, ypoly );
%
% could also use polygons inside polygons which are areas
%  that are not to be used.
%
%        & ...
%                      ~inpolygon( rndx_add, rndy_add, x_excpoly, y_excpoly );

        rndx = [rndx; rndx_add(isinpoly)];
        rndy = [rndy; rndy_add(isinpoly)];

        nrinpoly = length(rndx);

    end

    RNDX = [ RNDX; rndx(1:nrpoint) ];
    RNDY = [ RNDY; rndy(1:nrpoint) ];

end


