function simsoar_post_process

% simsoar_post_process
%
% This function generates the figures and tables on the basis of 
% simsoar-model output for the paper
% 'Understanding soaring bird migration through interactions and 
% decisions at the individual level'
% by E.E. van Loon, J.Z. Shamoun-Baranes, W. Bouten, S.L. Davis,
% submitted in december 2009 to Journal of Theoretical Biology
%
% The function uses data that results from the functions simsoar_base_run 
% and simsoar_sensitivity_analysis (simsoar_output.mat, 
% simsoar_output_v7_w90_d0.mat, simsoar_output_v7_w90_d1.mat, etc.)
% It writes out several summary-output files (simsoar_summary_output.mat,
% simsoar_summary_output_v7_w90_d0.mat, simsoar_summary_output_v7_w90_d1.mat, 
% etc.), png-files (Figure3.png, Figure4.png, AppB_NnearT_tv1.png etc.)
% and several sheets in the excel workbook jtb_tables.xls
%
% First study the various functions before you run them (some may take 
% some time). If you run the script make sure that jtb_tables.xls is
% not opened in excel, otherwise the matlab functions cannot write into
% the workbook. 
%
% The part of this function relating that processes the 
% Sensitivity-Analysis results is outcommented because generating the 
% summary output of the sensitivity analysis takes a long time (you don't 
% want to run it just for trying) while most relevant output is already 
% written to the excel-workbook jtb_tables.xls
%
%
%
% For questions, contact Emiel van Loon (vanloon@uva.nl)
% 
% Institute for Biodiversity and Ecosystem Dynamics
% University of Amsterdam
% Sciencepark 904
% 1098 XH Amsterdam
% The Netherlands



% summarize results of the base run and take a look at the 
% summary results
mkSummaryOutput

% generate Figures 3 and 4 as well as the figures in Appendix B
% to study the figures, look at the png-files, the text in the
% matlab-figures does not scale properly
pltFigure4
pltFigure5
pltFiguresAppendixB

% generate the data for the tables in the paper
% and write it to the correct worksheets in the 
% excel workbook jtb_tables.xls
mkTables


% % summarize the results of the sensitivity analysis, write the
% % results to an excel worksheet, and analyse results with a
% % multiple regression analysis
% % this part is outcommented by default because generating 
% % the summary output of the sensitivity analysis takes a long time
% % and most relevant output is already written to the excel-workbook
% % jtb_tables.xls
% 
% mkSummaryOutput_SA
% mkSensitivityAnalysis


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Below is the function that calculates summary output % 
% for the base run and show it on the screen           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function mkSummaryOutput

% mkSummaryOutput calls ppOutputStat, and saves results to 'simsoar_summary_output.mat'
% ppOutputStat is somewhere towards the end of this file

SumOut = ppOutputStat('simsoar_output.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
save('simsoar_summary_output.mat','SumOut')

% show the summary-results on the screen

t1 = SumOut.NnearT.tttsurv(:);
t2 = SumOut.NnearD.tttsurv(:);
t3 = SumOut.NfarT.tttsurv(:);
t4 = SumOut.NdirD.tttsurv(:);
t5 = SumOut.NrandT.tttsurv(:);
t6 = SumOut.SnearT.tttsurv(:);
t7 = SumOut.SnearD.tttsurv(:);
t8 = SumOut.SfarT.tttsurv(:);
t9 = SumOut.SdirD.tttsurv(:);
t10 = SumOut.SrandT.tttsurv(:);

ttt = [t1; t2; t3; t4; t5; t6; t7; t8; t9; t10];

nrhr = floor( nanmean(ttt)/3600 );
nrmin = round( 60 * ( nanmean(ttt)/3600 - nrhr ) ); 

% disp( [ 'mean time travelled: ' num2str(nrhr) ' hours and ' num2str(nrmin) ' minutes' ] )
% disp( [ 'std of time travelled: ' num2str( nanstd(ttt/60), 3) ' minutes' ] )


d1 = SumOut.NnearT.tdtsurv(:);
d2 = SumOut.NnearD.tdtsurv(:);
d3 = SumOut.NfarT.tdtsurv(:);
d4 = SumOut.NdirD.tdtsurv(:);
d5 = SumOut.NrandT.tdtsurv(:);
d6 = SumOut.SnearT.tdtsurv(:);
d7 = SumOut.SnearD.tdtsurv(:);
d8 = SumOut.SfarT.tdtsurv(:);
d9 = SumOut.SdirD.tdtsurv(:);
d10 = SumOut.SrandT.tdtsurv(:);

dt = [d1;d2;d3;d4;d5;d6;d7;d8;d9;d10];

disp( [ 'mean distance travelled: ' num2str( nanmean(dt)/1000, 3 ) ' km' ] )
disp( [ 'std distance travelled: ' num2str( nanstd(dt/1000), 2 ) ' km' ] )

v1 = SumOut.NnearT.tvsurv(:);
v2 = SumOut.NnearD.tvsurv(:);
v3 = SumOut.NfarT.tvsurv(:);
v4 = SumOut.NdirD.tvsurv(:);
v5 = SumOut.NrandT.tvsurv(:);
v6 = SumOut.SnearT.tvsurv(:);
v7 = SumOut.SnearD.tvsurv(:);
v8 = SumOut.SfarT.tvsurv(:);
v9 = SumOut.SdirD.tvsurv(:);
v10 = SumOut.SrandT.tvsurv(:);

tv = [v1;v2;v3;v4;v5;v6;v7;v8;v9;v10];

disp( [ 'mean nr of thermals visited: ' num2str( nanmean(tv), 2) ] )
disp( [ 'std of nr of thermals visited: ' num2str( nanstd(tv), 2) ] )


n1 = SumOut.NnearT.tn(:);
n2 = SumOut.NnearD.tn(:);
n3 = SumOut.NfarT.tn(:);
n4 = SumOut.NdirD.tn(:);
n5 = SumOut.NrandT.tn(:);
n6 = SumOut.SnearT.tn(:);
n7 = SumOut.SnearD.tn(:);
n8 = SumOut.SfarT.tn(:);
n9 = SumOut.SdirD.tn(:);
n10 = SumOut.SrandT.tn(:);

tn = [n1;n2;n3;n4;n5;n6;n7;n8;n9;n10];

disp( [ 'mean nr of unique thermals visited by all 200 birds: ' num2str( nanmean(tn), 3 ) ] )
disp( [ 'std of unique thermals visited by all 200 birds: ' num2str( nanstd(tn), 3 ) ] )


%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Below is the function (with helper-functions to plot Figure 3 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function pltFigure4
% Figure 4. Typical model results when simulating white stork migration. 
% The top row shows travel networks when using decision rules 1 to 5 and 
% the bottom row shows the travel networks when using decision rule 6 to 10. 
% For all simulations the same parameters are used (viz. Table 4), only 
% the location of the thermals differs between the two.

fieldnr = 1;
filename = 'simsoar_output.mat';

a1 = ['NnearT' num2str(fieldnr)];
a2 = ['NfarT' num2str(fieldnr)];
a3 = ['NnearD' num2str(fieldnr)];
a4 = ['NdirD' num2str(fieldnr)];
a5 = ['NrandT' num2str(fieldnr)];
a6 = ['SnearT' num2str(fieldnr)];
a7 = ['SfarT' num2str(fieldnr)];
a8 = ['SnearD' num2str(fieldnr)];
a9 = ['SdirD' num2str(fieldnr)]; 
a10 = ['SrandT' num2str(fieldnr)];

birdmov = {a1, a2, a3, a4, a5, a6, a7, a8, a9, a10};

load( filename, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10);

therm = ['Thermal' num2str(fieldnr)'];

load('simsoar_input.mat','Bound',therm)

w = 0.17;
h = 0.45;
axpos = [0.04 0.5 w h
         0.22 0.5 w h
         0.40 0.5 w h
         0.58 0.5 w h
         0.76 0.5 w h
         0.04 0.03 w h
         0.22 0.03 w h
         0.40 0.03 w h
         0.58 0.03 w h
         0.76 0.03 w h];
     
figure
for i =1:10
    axh(i) = axes('position',axpos(i,:));
    eval( ['pltMovement2D(Bound,' therm ',' birdmov{i} ')'] )
    set(gca,'YDir','reverse')
end

axes('position',[0 0 1 1]);
axis([0 1 0 1]), hold on;

for i=1:10
    p=plot(axpos(i,1)+ 0.005, axpos(i,2)+0.43,'ko');
    set(p,'Markersize',16,'MarkerFacecolor',[1 1 1])
    text(axpos(i,1)+ 0.005, axpos(i,2)+0.43, num2str(i),'horizontalalignment','center')
end

th1=text(0.125,1,{'nearest thermal'},'Fontsize',11,'VerticalAlignment','top','HorizontalAlignment','center');
th2=text(0.305,1,{'furthest thermal'},'Fontsize',11,'VerticalAlignment','top','HorizontalAlignment','center');
th3=text(0.485,1,{'thermal nearest to','destination'},'Fontsize',11,'VerticalAlignment','top','HorizontalAlignment','center');
th4=text(0.665,1,{'thermal nearest to','destination direction'},'Fontsize',11,'VerticalAlignment','top','HorizontalAlignment','center');
th5=text(0.845,1,{'random thermal'},'Fontsize',11,'VerticalAlignment','top','HorizontalAlignment','center');

th6=text(0.02,0.725,'Non-Social birds','Fontsize',11,'Rotation',90,'HorizontalAlignment','center');
th7=text(0.02,0.255,'Social birds','Fontsize',11,'Rotation',90,'HorizontalAlignment','center');

% th8=text(0.97,0.77,'flight direction','Fontsize',11,'Rotation',270,'color',[0.5 0.5 0.5]);
th9=text(0.954,0.32,'flight direction','Fontsize',11,'Rotation',270,'color',[0.5 0.5 0.5]);
ha2 = annotation('arrow', [0.939 0.939], [0.32 0.12],'color',[0.5 0.5 0.5],'linewidth', 1);

th11 = annotation('textarrow',[0.86 0.82],[0.492,0.47],'Color',[0.5 0.5 0.5],...
     'String',{' departure area'},'HeadStyle','none','LineWidth',1,'Fontsize',9, 'TextMargin', 0);
th12 = annotation('textarrow',[0.86 0.82],[0.02,0.04],'Color',[0.5 0.5 0.5],...
     'String',{' destination area'},'HeadStyle','none','LineWidth',1,'Fontsize',9, 'TextMargin', 0 );

% ha1 = annotation('arrow', [0.959 0.959],[0.77 0.57]);
% set(ha1,'color',[0.5 0.5 0.5],'linewidth', 1);

axis off;

print('Figure4.png','-dpng')
print('Figure4.pdf','-dpdf')


%%

function pltMovement2D(Bound,Thermal,Moves)
%
%   pltMovement2D(bound,thermal,bird)
%
% Display bird movement and thermals in 2D.
% Bird trajectories are shown as lines.
%

% Emiel van Loon <vanloon@uva.nl>
% December 2006

% x indiv in cols; timeframes in rows;
x = Moves.X';
y = Moves.Y';

%display domain
hpdo = plot(Bound.DomainPoly(:,1), Bound.DomainPoly(:,2), 'k-','linewidth',1);
set(hpdo,'color',[0.3, 0.3, 0.3])
axis equal;
axis tight;
acx = 0.02 * ( max(Bound.DomainPoly(:,1)) - min(Bound.DomainPoly(:,1)) );  % axis correction x-range
acy = 0.02 * ( max(Bound.DomainPoly(:,2)) - min(Bound.DomainPoly(:,2)) );  % axis correctino y-range
axis( [ min(Bound.DomainPoly(:,1)) - acx,  max(Bound.DomainPoly(:,1)) + acx, ...
        min(Bound.DomainPoly(:,2)) - acy,  max(Bound.DomainPoly(:,2)) + acy] );
axis off
%axis tight; 
hold on;

%display destination
hpde = plot(Bound.DestPoly(:,1),Bound.DestPoly(:,2), 'k:', 'linewidth', 2);

%display thermals
for i = 1:length(Thermal.ID)   
    ch = circle([Thermal.X(i) Thermal.Y(i)], Thermal.Radius(i), 100, 'k-');
    set(ch, 'color', [0.5 0.5 0.5])
end
 
% display bird-trajectories
hp = plot( x, y, 'k-' , 'linewidth', 1);



function H=circle(center,radius,NOP,style)
%---------------------------------------------------------------------------------------------
% H=CIRCLE(CENTER,RADIUS,NOP,STYLE)
% This routine draws a circle with center defined as
% a vector CENTER, radius as a scaler RADIS. NOP is 
% the number of points on the circle. As to STYLE,
% use it the same way as you use the rountine PLOT.
% Since the handle of the object is returned, you
% use routine SET to get the best result.
%
%   Usage Examples,
%
%   circle([1,3],3,1000,':'); 
%   circle([2,4],2,1000,'--');
%
%   Zhenhai Wang <zhenhai@ieee.org>
%   Version 1.00
%   December, 2002
%---------------------------------------------------------------------------------------------

if (nargin <3),
 error('Please see help for INPUT DATA.');
elseif (nargin==3)
    style='b-';
end;
THETA=linspace(0,2*pi,NOP);
RHO=ones(1,NOP)*radius;
[X,Y] = pol2cart(THETA,RHO);
X=X+center(1);
Y=Y+center(2);
H=plot(X,Y,style,'linewidth',1.5);
%axis square;
%hold on

%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Below is the function to plot Figure 5  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function pltFigure5

% pltFigure5 
% Function plots Figure 5, the distributions and averages nr of thermals 
% vistited and relative distance traveled per decision rule, not over birds
% or thermals

load('simsoar_summary_output.mat','SumOut')

hypoN = {'NnearT','NfarT','NnearD','NdirD','NrandT'};
hypoS = {'SnearT', 'SfarT','SnearD','SdirD','SrandT'};
       
w = 0.44;
h = 0.15;
axpos = [0.06 0.80 w h
         0.06 0.62 w h
         0.06 0.44 w h
         0.06 0.26 w h
         0.06 0.08 w h
         0.54 0.80 w h
         0.54 0.62 w h
         0.54 0.44 w h
         0.54 0.26 w h
         0.54 0.08 w h];
     
tvxi = 30:0.05:80;
dtxi = 1.05:0.0005:1.25;

figure;

%%%
% nr of thermals visited (left side of figure)
%%%

for i = 1:5

    eval( [ 'atvbN = SumOut.' hypoN{i} '.tvsurv(:);'] );
    eval( [ 'atvbS = SumOut.' hypoS{i} '.tvsurv(:);'] );

    [fbN,x,btvbN] = ksdensity(atvbN,tvxi,'width',2);
    [fbS,x,btvbS] = ksdensity(atvbS,tvxi,'width',2);

    tvfbN = fbN/sum(fbN);
    tvfbS = fbS/sum(fbS);

    ax = axes( 'position', axpos(i,:) );
    p = plot( tvxi, tvfbN, 'k-', tvxi, tvfbS, 'k-',...
                nanmean(atvbN),0.0005,'k^', nanmean(atvbS),0.0005,'ko') ; 

    axis( [ min(tvxi) max(tvxi) 0 0.01 ]);
    box off;
    set( p(1), 'linewidth', 1.5, 'color', [0.7 0.7 0.7] );
    set( p(2), 'linewidth', 1, 'color', [0 0 0] );
    set( p(3), 'markerfacecolor',[0.7 0.7 0.7], 'markeredgecolor',[0.7 0.7 0.7]);
    set( p(4), 'linewidth', 1);
    
    set(ax,'Ytick',[0 0.005 0.01], 'YAxisLocation', 'right', 'YTickLabel', []) 

     if i<5
         set(ax,'Xticklabel',[]);
     end

end

%%%
% relative distance traveled (right side of figure)
%%%

for i = 1:5

    eval( [ 'adtbN = SumOut.' hypoN{i} '.tdtsurv(:)/200000;'] );
    eval( [ 'adtbS = SumOut.' hypoS{i} '.tdtsurv(:)/200000;'] );

    [fbN,x,bdtbN] = ksdensity(adtbN,dtxi,'width',0.01);
    [fbS,x,bdtbS] = ksdensity(adtbS,dtxi,'width',0.01);

    dtfbN = fbN/sum(fbN);
    dtfbS = fbS/sum(fbS);

    ax = axes( 'position', axpos(i+5,:) );
    p = plot( dtxi, dtfbN, 'k-', dtxi, dtfbS, 'k-',...
                nanmean(adtbN),0.0005,'k^', nanmean(adtbS),0.0005,'ko'); 
    axis( [ min(dtxi) max(dtxi) 0 0.01 ]);
        
    set( p(1), 'linewidth', 1.5, 'color', [0.7 0.7 0.7] );
    set( p(2), 'linewidth', 1, 'color', [0 0 0] );
    set( p(3), 'markerfacecolor',[0.7 0.7 0.7], 'markeredgecolor',[0.7 0.7 0.7]);
    set( p(4), 'linewidth', 1);

    box off;
    set(ax,'Yticklabel',[])
    
    if i<5
        set(ax,'Xticklabel',[]);
    end

    if i==5
        lh = legend( 'prob. non-social', 'prob. social', 'average non-social', 'average social');
        set(lh,'position',[0.82 0.26 0.1 0.20],'box','off','fontsize',12)
    end

end

axes('position',[0 0 1 1]);
axis([0 1 0 1]);
hold on;

tsft1 = 0.09;
tsft2 = 0.06;
text(0.01,axpos(1,2)+tsft1,'nearest thermal (rules 1 & 6)')
text(0.01,axpos(2,2)+tsft1,'furthest thermal (rules 2 & 7)')
text(0.01,axpos(3,2)+tsft1,'thermal nearest to')
text(0.02,axpos(3,2)+tsft2,'destination (rules 3 & 8)')
text(0.01,axpos(4,2)+tsft1,'thermal nearest to')
text(0.02,axpos(4,2)+tsft2,'destination direction (rules 4 & 9)')
text(0.01,axpos(5,2)+tsft1,'random thermal (rules 5 & 10)')

psht = 0.15;
text(0.45,axpos(1,2)+psht,'0.01')
text(0.45,axpos(2,2)+psht,'0.01')
text(0.45,axpos(3,2)+psht,'0.01')
text(0.45,axpos(4,2)+psht,'0.01')
text(0.45,axpos(5,2)+psht,'0.01')
text(0.56,axpos(1,2)+psht,'0.1')
text(0.56,axpos(2,2)+psht,'0.1')
text(0.56,axpos(3,2)+psht,'0.1')
text(0.56,axpos(4,2)+psht,'0.1')
text(0.56,axpos(5,2)+psht,'0.1')

text(0.515,axpos(1,2)+ 0.01,'0')
text(0.515,axpos(2,2)+ 0.01,'0')
text(0.515,axpos(3,2)+ 0.01,'0')
text(0.515,axpos(4,2)+ 0.01,'0')
text(0.515,axpos(5,2)+ 0.01,'0')


text(0.52,0.98,'probability','HorizontalAlignment','Center')

text(0.28,0.01,'number of thermals visited (nb)','HorizontalAlignment',...
    'Center','VerticalAlignment','Bottom','Fontsize',12)
text(0.76,0.01,'relative distance travelled (m m^{-1})','HorizontalAlignment',...
    'Center','VerticalAlignment','Bottom','Fontsize',12)

lm = 0.04;     % parameter to change left margin for label 'a'
rm = 0.00;     % parameter to change right margin for label 'b'
abcol = [0.7 0.7 0.7];
line([0.01+lm 0.47],[0.99 0.99],'color',abcol,'linewidth',1.5);
line([0.57 0.98-rm],[0.99 0.99],'color',abcol,'linewidth',1.5);
patch([0.01 0.04 0.04 0.01 0.01]+lm,[0.92 0.92 0.99 0.99 0.92],abcol,...
      'edgecolor', abcol, 'linewidth',1.5);
patch([0.99 0.96 0.96 0.99 0.99]-rm,[0.92 0.92 0.99 0.99 0.92],abcol,...
      'edgecolor', abcol, 'linewidth',1.5);
text( 0.015+lm, 0.95,'\bf{a}','fontsize',18,'color',[0 0 0]);
text( 0.965-rm, 0.95,'\bf{b}','fontsize',18,'color',[0 0 0]);

axis off

print('Figure5.png','-dpng');
print('Figure5.pdf','-dpdf');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Below is the function to plot the figures of Appendix B %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function pltFiguresAppendixB

% pltFiguresAppendixB
% Function plots figures of Appendix B, checkerboard plots of nr of thermals 
% visited and relative distance traveled (i.e. values per bird and thermal
% field.

load('simsoar_summary_output.mat')

cm = colormap;

tv{1} = SumOut.NnearT.tvsurv;
rdt{1} = SumOut.NnearT.dtsurv;

tv{2} = SumOut.NfarT.tvsurv;
rdt{2} = SumOut.NfarT.dtsurv;

tv{3} = SumOut.NnearD.tvsurv;
rdt{3} = SumOut.NnearD.dtsurv;

tv{4} = SumOut.NdirD.tvsurv;
rdt{4} = SumOut.NdirD.dtsurv;

tv{5} = SumOut.NrandT.tvsurv;
rdt{5} = SumOut.NrandT.dtsurv;

tv{6} = SumOut.SnearT.tvsurv;
rdt{6} = SumOut.SnearT.dtsurv;

tv{7} = SumOut.SfarT.tvsurv;
rdt{7} = SumOut.SfarT.dtsurv;

tv{8} = SumOut.SnearD.tvsurv;
rdt{8} = SumOut.SnearD.dtsurv;

tv{9} = SumOut.SdirD.tvsurv;
rdt{9} = SumOut.SdirD.dtsurv;

tv{10} = SumOut.SrandT.tvsurv;
rdt{10} = SumOut.SrandT.dtsurv;

% tv_mi = min( [ min(tv1(:)), min(tv2(:)), min(tv3(:)), min(tv4(:)), min(tv5(:)), ...
%                 min(tv6(:)), min(tv7(:)), min(tv8(:)), min(tv9(:)), min(tv10(:))] );
% tv_ma = max( [ max(tv1(:)), max(tv2(:)), max(tv3(:)), max(tv4(:)), max(tv5(:)), ...
%                 max(tv6(:)), max(tv7(:)), max(tv8(:)), max(tv9(:)), max(tv10(:))] );
% rdt_mi = min( [ min(rdt1(:)), min(rdt2(:)), min(rdt3(:)), min(rdt4(:)), min(rdt5(:)), ...
%                  min(rdt6(:)), min(rdt7(:)), min(rdt8(:)), min(rdt9(:)), min(rdt10(:))] );           
% rdt_ma = max( [ max(rdt1(:)), max(rdt2(:)), max(rdt3(:)), max(rdt4(:)), max(rdt5(:)), ...
%                  max(rdt6(:)), max(rdt7(:)), max(rdt8(:)), max(rdt9(:)), max(rdt10(:))] );
% 
% result: 
% 
% tv_mi =  29;
% tv_ma =  87
% rdt_mi = 1.0544
% rdt_ma = 1.3315
%
% and these values are used for the color-scales in the figures:

tvlow = 20;
rdtlow = 1;

tvclim = [tvlow 90];
rdtclim = [rdtlow 1.30];
cm(1,:) = [1 1 1];

for i = 1:10
  tv{i}( isnan(tv{i}) ) = tvlow;
  rdt{i}( isnan(rdt{i}) ) = rdtlow;
end

Tit = {'Decision rule 1: non-social, selecting nearest thermal',...
       'Decision rule 2: non-social, selecting furthest thermal',...
       'Decision rule 3: non-social, selecting thermal nearest to destination',...
       'Decision rule 4: non-social, selecting thermal nearest to dest. direction',...
       'Decision rule 5: non-social, selecting random thermal',...
       'Decision rule 6: social, selecting nearest thermal',...
       'Decision rule 7: social, selecting furthest thermal',...
       'Decision rule 8: social, selecting thermal nearest to destination',...
       'Decision rule 9: social, selecting thermal nearest to dest. direction',...
       'Decision rule 10: social, selecting random thermal'};
   
tvFname = {'AppB_NnearT_tv1.png',...
           'AppB_NfarT_tv2.png',...
           'AppB_NnearD_tv3.png',...
           'AppB_NdirD_tv4.png',...
           'AppB_NrandT_tv5.png',...
           'AppB_SnearT_tv6.png',...
           'AppB_SfarT_tv7.png',...
           'AppB_SnearD_tv8.png',...
           'AppB_SdirD_tv9.png',...
           'AppB_SrandT_tv10.png'};
       
rdtFname = {'AppB_NnearT_rdt1.png',...
            'AppB_NfarT_rdt2.png',...
            'AppB_NnearD_rdt3.png',...
            'AppB_NdirD_rdt4.png',...
            'AppB_NrandT_rdt5.png',...
            'AppB_SnearT_rdt6.png',...
            'AppB_SfarT_rdt7.png',...
            'AppB_SnearD_rdt8.png',...
            'AppB_SdirD_rdt9.png',...
            'AppB_SrandT_rdt10.png'};    
    
close all

for i = 1:10
    
    imagesc( tv{i} ); axis equal; axis tight; colormap(cm); 
    set(gca,'clim', tvclim); hold on;
    title(Tit{i},'fontsize',12);
    xlabel('thermal field','fontsize',12)
    ylabel('bird','fontsize',12)
    lh = colorbar;
    set(lh,'ytick', [30 40 50 60 70 80]);
    text(213,-8,'\it{tv}','fontsize',14)
    axes('position',[0 0 1 1]); axis([0 1 0 1]); hold on; axis off;
    text(0.86,0.11,{'not reaching','destination'})
    plot([0.83 0.85],[0.115 0.115],'k-','linewidth',1);
    print(tvFname{i},'-dpng')
    close gcf
    
    imagesc( rdt{i} ); axis equal; axis tight; colormap(cm); hold on;
    set(gca,'clim', rdtclim); hold on;
    title(Tit{i},'fontsize',12);
    xlabel('thermal field','fontsize',12)
    ylabel('bird','fontsize',12)
    lh = colorbar;
    set(lh,'ytick', [1.05 1.10 1.15 1.20 1.25 1.30]);
    text(212,-8,'\it{rdt}','fontsize',14)
    axes('position',[0 0 1 1]); axis([0 1 0 1]); hold on; axis off;
    text(0.86,0.11,{'not reaching','destination'})
    plot([0.83 0.85],[0.115 0.115],'k-','linewidth',1);
    print(rdtFname{i},'-dpng')
    close gcf
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Below is the function to conduct some analyses and write %
% Tables 5, 6, 7 and B1 to an excel workbook               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function mkTables

load('simsoar_summary_output.mat')
xlsfilename = 'jtb_tables.xls';


%%%%
% make calculations on sample size and write Table6
%%%%

sheetname = 'Table6';

% determine how much samples are required to find an effect
% N=SAMPSIZEPWR('TESTTYPE',P0,P1,POWER)
pwr = 0.8;

% we calculate sample size for all thermal fields and birds combined 
% data are not averaged
    
    T{1} = [ nanmean(SumOut.NnearT.tvsurv(:)) nanstd(SumOut.NnearT.tvsurv(:)) ];
    T{2} = [ nanmean(SumOut.NfarT.tvsurv(:)) nanstd(SumOut.NfarT.tvsurv(:)) ];
    T{3} = [ nanmean(SumOut.NnearD.tvsurv(:)) nanstd(SumOut.NnearD.tvsurv(:)) ];
    T{4} = [ nanmean(SumOut.NdirD.tvsurv(:)) nanstd(SumOut.NdirD.tvsurv(:)) ];
    T{5} = [ nanmean(SumOut.NrandT.tvsurv(:)) nanstd(SumOut.NrandT.tvsurv(:)) ];
    T{6} = [ nanmean(SumOut.SnearT.tvsurv(:)) nanstd(SumOut.SnearT.tvsurv(:)) ];
    T{7} = [ nanmean(SumOut.SfarT.tvsurv(:)) nanstd(SumOut.SfarT.tvsurv(:)) ];
    T{8} = [ nanmean(SumOut.SnearD.tvsurv(:)) nanstd(SumOut.SnearD.tvsurv(:)) ];
    T{9} = [ nanmean(SumOut.SdirD.tvsurv(:)) nanstd(SumOut.SdirD.tvsurv(:)) ];
    T{10} = [ nanmean(SumOut.SrandT.tvsurv(:)) nanstd(SumOut.SrandT.tvsurv(:)) ];
    R{1} = [ nanmean(SumOut.NnearT.tdtsurv(:)) nanstd(SumOut.NnearT.tdtsurv(:)) ];
    R{2} = [ nanmean(SumOut.NfarT.tdtsurv(:)) nanstd(SumOut.NfarT.tdtsurv(:)) ];
    R{3} = [ nanmean(SumOut.NnearD.tdtsurv(:)) nanstd(SumOut.NnearD.tdtsurv(:)) ];
    R{4} = [ nanmean(SumOut.NdirD.tdtsurv(:)) nanstd(SumOut.NdirD.tdtsurv(:)) ];
    R{5} = [ nanmean(SumOut.NrandT.tdtsurv(:)) nanstd(SumOut.NrandT.tdtsurv(:)) ];
    R{6} = [ nanmean(SumOut.SnearT.tdtsurv(:)) nanstd(SumOut.SnearT.tdtsurv(:)) ];
    R{7} = [ nanmean(SumOut.SfarT.tdtsurv(:)) nanstd(SumOut.SfarT.tdtsurv(:)) ];
    R{8} = [ nanmean(SumOut.SnearD.tdtsurv(:)) nanstd(SumOut.SnearD.tdtsurv(:)) ];
    R{9} = [ nanmean(SumOut.SdirD.tdtsurv(:)) nanstd(SumOut.SdirD.tdtsurv(:)) ];
    R{10} = [ nanmean(SumOut.SrandT.tdtsurv(:)) nanstd(SumOut.SrandT.tdtsurv(:)) ];
     
    for i = 1:10
        for j = 1:10
            
            if j==i
                N(i,j)=NaN;
            end
            
            if j>i
                n = sampsizepwr('t',T{i},T{j},pwr);
                N(j,i) =  n(1);
                n =  sampsizepwr('t',R{i},R{j},pwr);
                N(i,j) = n(1);
            end
            
        end
    end
    
xlswrite( xlsfilename,N,sheetname,'B4');

%%%%
% write average and std (aggregated over birds
% and thermals) for thermals visited,
% relative distance traveled (etc.) per decision rule
% to TableB1 (Table 7 is calculated in the spreadsheet
% and based entirely on the values in TableB1
%%%%

sheetname = 'TableB1';

hypolbl = {'NnearT', 'NfarT', 'NnearD', 'NdirD', 'NrandT', 'SnearT', 'SfarT', 'SnearD', 'SdirD', 'SrandT'};
fieldlbl = {'sr','es','dt','tv','tr'};

%%%

disp('Writing average & std of nr of thermals visited to xls-file')

atv = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.atv;' ] );
    atv{i} = data ;
end

% std aggregated per bird
stv_bird = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.atvb;' ] );
    sd = std(data);
    stv_bird{i} = sd;
end

% std aggregated per thermal
stv_therm = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.atvt;' ] );
    sd = std(data);
    stv_therm{i} = sd;
end

% std between 200 birds within per thermal (200 std's averaged)
stv_sbird = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.tvsurv;' ] );
    sd = nanmean(nanstd(data));
    stv_sbird{i} = sd;
end

% std between 200 thermal fields per bird (200 std's averaged)
stv_stherm = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.tvsurv;' ] );
    sd = nanmean(nanstd(data,0,2));          % std in horizontal direction!
    stv_stherm{i} = sd;
end

xlswrite( xlsfilename,atv,sheetname,'b7');
xlswrite( xlsfilename,stv_bird,sheetname,'c7');
xlswrite( xlsfilename,stv_therm,sheetname,'d7');
xlswrite( xlsfilename,stv_sbird,sheetname,'f7');
xlswrite( xlsfilename,stv_stherm,sheetname,'g7');

%%%

disp('Writing average & std of rel. distance traveled to xls-file')

adt = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.adt;' ] );
    adt{i} = data ;
end

sdt_bird = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.adtb;' ] );
    sd = std(data);
    sdt_bird{i} = sd;
end

sdt_therm = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.adtt;' ] );
    sd = std(data);
    sdt_therm{i} = sd;
end

% std between 200 birds within per thermal (200 std's averaged)
sdt_sbird = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.tdtsurv;' ] );
    sd = nanmean(nanstd(data./200000));
    sdt_sbird{i} = sd;
end

% std between 200 thermal fields per bird (200 std's averaged)
sdt_stherm = cell(10,1);
for i = 1:10
    eval( [ 'data = SumOut.' hypolbl{i} '.tdtsurv;' ] );
    sd = nanmean(nanstd(data/200000,0,2));          % std in horizontal direction!
    sdt_stherm{i} = sd;
end

xlswrite( xlsfilename,adt,sheetname,'b20');
xlswrite( xlsfilename,sdt_bird,sheetname,'c20');
xlswrite( xlsfilename,sdt_therm,sheetname,'d20');
xlswrite( xlsfilename,sdt_sbird,sheetname,'f20');
xlswrite( xlsfilename,sdt_stherm,sheetname,'g20');

%%%%
% Write average distance to thermal and std to Table 7
%%%%

sheetname = 'Table7';

d1 = SumOut.NnearT.tdtsurv(:)./1000;
d2 = SumOut.NnearD.tdtsurv(:)./1000;
d3 = SumOut.NfarT.tdtsurv(:)./1000;
d4 = SumOut.NdirD.tdtsurv(:)./1000;
d5 = SumOut.NrandT.tdtsurv(:)./1000;
d6 = SumOut.SnearT.tdtsurv(:)./1000;
d7 = SumOut.SnearD.tdtsurv(:)./1000;
d8 = SumOut.SfarT.tdtsurv(:)./1000;
d9 = SumOut.SdirD.tdtsurv(:)./1000;
d10 = SumOut.SrandT.tdtsurv(:)./1000;

v1 = SumOut.NnearT.tvsurv(:);
v2 = SumOut.NnearD.tvsurv(:);
v3 = SumOut.NfarT.tvsurv(:);
v4 = SumOut.NdirD.tvsurv(:);
v5 = SumOut.NrandT.tvsurv(:);
v6 = SumOut.SnearT.tvsurv(:);
v7 = SumOut.SnearD.tvsurv(:);
v8 = SumOut.SfarT.tvsurv(:);
v9 = SumOut.SdirD.tvsurv(:);
v10 = SumOut.SrandT.tvsurv(:);

avgterdis = [ nanmean(d1./v1)
  nanmean(d2./v2)
  nanmean(d3./v3)
  nanmean(d4./v4)
  nanmean(d5./v5)
  nanmean(d6./v6)
  nanmean(d7./v7)
  nanmean(d8./v8)
  nanmean(d9./v9)
  nanmean(d10./v10)];

stdterdis = [ nanstd(d1./v1)
  nanstd(d2./v2)
  nanstd(d3./v3)
  nanstd(d4./v4)
  nanstd(d5./v5)
  nanstd(d6./v6)
  nanstd(d7./v7)
  nanstd(d8./v8)
  nanstd(d9./v9)
  nanstd(d10./v10)];

xlswrite( xlsfilename,avgterdis,sheetname,'b5');
xlswrite( xlsfilename,stdterdis,sheetname,'c5');


%%%%
% ANOVA and multi-comparison tests
%%%%

%
% % 1-way ANOVA + multicomparison test to see whether the
% % decision rule within a non-social or social group (1 to 5) and 
% % (6 to 10) significantly influences the number of thermals visited 
% % and travel time.
% %
% 
% load('simsoar_summary_output.mat')
% 
% x = repmat( (1:5), 200, 1);
% ns_gr = x(:);
% ns_tv = [SumOut.NnearT.atvb;
%          SumOut.NfarT.atvb;
%          SumOut.NnearD.atvb;
%          SumOut.NdirD.atvb;
%          SumOut.NrandT.atvb];
% 
% [ns_tvp, ns_tva, ns_tvs] = anova1( ns_tv, ns_gr);
% [ns_tvc,ns_tvm,ns_tvh,ns_tvn] = multcompare(ns_tvs);
% 
% % Source     SS      df      MS         F       Prob>F
% % ----------------------------------------------------
% % Groups   16218.8     4   4054.71   60073.75     0   
% % Error       67.2   995      0.07                    
% % Total    16286     999                              
% 
% % values in ns_c =
% %
% %     1.0000    2.0000    9.9018    9.9727   10.0435
% %     1.0000    3.0000   11.0474   11.1182   11.1891
% %     1.0000    4.0000    9.1338    9.2046    9.2755
% %     1.0000    5.0000    5.6474    5.7183    5.7892
% %     2.0000    3.0000    1.0747    1.1456    1.2165
% %     2.0000    4.0000   -0.8389   -0.7680   -0.6972
% %     2.0000    5.0000   -4.3252   -4.2544   -4.1835
% %     3.0000    4.0000   -1.9845   -1.9136   -1.8427
% %     3.0000    5.0000   -5.4708   -5.4000   -5.3291
% %     4.0000    5.0000   -3.5572   -3.4863   -3.4155
% 
% % determine how much samples are required to find an effect
% % N=SAMPSIZEPWR('TESTTYPE',P0,P1,POWER)
% pwr = 0.9;
% P1 = [ mean(SumOut.NnearT.atvb) std(SumOut.NnearT.atvb) ];
% P2 = [ mean(SumOut.NfarT.atvb) std(SumOut.NfarT.atvb) ];
% P3 = [ mean(SumOut.NnearD.atvb) std(SumOut.NnearD.atvb) ];
% P4 = [ mean(SumOut.NdirD.atvb) std(SumOut.NdirD.atvb) ];
% P5 = [ mean(SumOut.NrandT.atvb) std(SumOut.NrandT.atvb) ];
% 
% n12 = sampsizepwr('t',P1,P2,pwr)
% n13 = sampsizepwr('t',P1,P3,pwr)
% n14 = sampsizepwr('t',P1,P4,pwr)
% n15 = sampsizepwr('t',P1,P5,pwr)
% n23 = sampsizepwr('t',P2,P3,pwr)
% n24 = sampsizepwr('t',P2,P4,pwr)
% n25 = sampsizepwr('t',P2,P5,pwr)
% n34 = sampsizepwr('t',P3,P4,pwr)
% n35 = sampsizepwr('t',P3,P5,pwr)
% n45 = sampsizepwr('t',P4,P5,pwr)
% 
% x = repmat( (5:10), 200, 1);
% s_gr = x(:);
% s_tv = [SumOut.SnearT.atvb;
%         SumOut.SfarT.atvb;
%         SumOut.SnearD.atvb;
%         SumOut.SdirD.atvb;
%         SumOut.SrandT.atvb ];
% [s_p, s_a, s_st] = anova1( s_tv, s_gr);
% [s_c,s_m,s_h,s_nm] = multcompare(s_st);
% [s_nm num2cell(s_m)]   
%  
% % Source     SS      df      MS        F      Prob>F
% % --------------------------------------------------
% % Groups   19151.3     4   4787.81   1940.5     0   
% % Error     2455     995      2.47                  
% % Total    21606.2   999                            
% 
% % s_c =
% % 
% %     1.0000    2.0000   11.0993   11.5278   11.9563
% %     1.0000    3.0000   10.8772   11.3057   11.7342
% %     1.0000    4.0000    7.2270    7.6554    8.0839
% %     1.0000    5.0000   10.5170   10.9455   11.3740
% %     2.0000    3.0000   -0.6506   -0.2221    0.2064
% %     2.0000    4.0000   -4.3008   -3.8724   -3.4439
% %     2.0000    5.0000   -1.0108   -0.5823   -0.1539
% %     3.0000    4.0000   -4.0787   -3.6503   -3.2218
% %     3.0000    5.0000   -0.7887   -0.3602    0.0683
% %     4.0000    5.0000    2.8616    3.2900    3.7185
% 
% % sample size calculations for the Social decision rules
% pwr = 0.9;
% P6 = [ mean(SumOut.SnearT.atvb) std(SumOut.SnearT.atvb) ];
% P7 = [ mean(SumOut.SfarT.atvb) std(SumOut.SfarT.atvb) ];
% P8 = [ mean(SumOut.SnearD.atvb) std(SumOut.SnearD.atvb) ];
% P9 = [ mean(SumOut.SdirD.atvb) std(SumOut.SdirD.atvb) ];
% P10 = [ mean(SumOut.SrandT.atvb) std(SumOut.SrandT.atvb) ];
% 
% n67 = sampsizepwr('t',P6,P7,pwr); N67 = N67(1)
% n68 = sampsizepwr('t',P6,P8,pwr)
% n69 = sampsizepwr('t',P6,P9,pwr)
% n610 = sampsizepwr('t',P6,P10,pwr)
% n78 = sampsizepwr('t',P7,P8,pwr)
% n79 = sampsizepwr('t',P7,P9,pwr)
% n710 = sampsizepwr('t',P7,P10,pwr)
% n89 = sampsizepwr('t',P8,P9,pwr)
% n810 = sampsizepwr('t',P8,P10,pwr)
% n910 = sampsizepwr('t',P9,P10,pwr)
% 
% 
% x = repmat( (1:5), 200, 1);
% ns_gr = x(:);
% ns_dt = [SumOut.NnearT.adtb;
%          SumOut.NfarT.adtb;
%          SumOut.NnearD.adtb;
%          SumOut.NdirD.adtb;
%          SumOut.NrandT.adtb];
% 
% [ns_dtp, ns_dta, ns_dts] = anova1( ns_dt, ns_gr);
% [ns_dtc,ns_dtm,ns_dth,ns_dtn] = multcompare(ns_dts);
% 
% 
% % Source     SS      df      MS         F       Prob>F
% % ----------------------------------------------------
% % Groups   0.52939     4   0.13235   20606.71     0   
% % Error    0.00639   995   0.00001                    
% % Total    0.53578   999                              
% %
% %
% % ns_dtc =
% % 
% %     1.0000    2.0000   -0.0035   -0.0028   -0.0021
% %     1.0000    3.0000    0.0361    0.0368    0.0375
% %     1.0000    4.0000    0.0512    0.0519    0.0526
% %     1.0000    5.0000   -0.0026   -0.0019   -0.0012
% %     2.0000    3.0000    0.0389    0.0396    0.0403
% %     2.0000    4.0000    0.0540    0.0547    0.0554
% %     2.0000    5.0000    0.0002    0.0009    0.0016
% %     3.0000    4.0000    0.0144    0.0151    0.0158
% %     3.0000    5.0000   -0.0394   -0.0387   -0.0380
% %     4.0000    5.0000   -0.0545   -0.0538   -0.0531
% 
% x = repmat( (5:10), 200, 1);
% s_gr = x(:);
% s_dt = [SumOut.SnearT.adtb;
%         SumOut.SfarT.adtb;
%         SumOut.SnearD.adtb;
%         SumOut.SdirD.adtb;
%         SumOut.SrandT.adtb ];
% [s_dtp, s_dta, s_dts] = anova1( s_dt, s_gr);
% [s_dtc, s_dtm, s_dth, s_dtn] = multcompare(s_dts);
% 
% % Source     SS      df      MS         F      Prob>F
% % ---------------------------------------------------
% % Groups   0.56976     4   0.14244   24976.2     0   
% % Error    0.00567   995   0.00001                   
% % Total    0.57543   999                             
% % 
% % s_dtc =
% % 
% %     1.0000    2.0000   -0.0037   -0.0030   -0.0024
% %     1.0000    3.0000    0.0324    0.0330    0.0337
% %     1.0000    4.0000    0.0479    0.0486    0.0492
% %     1.0000    5.0000   -0.0151   -0.0145   -0.0138
% %     2.0000    3.0000    0.0354    0.0361    0.0367
% %     2.0000    4.0000    0.0510    0.0516    0.0523
% %     2.0000    5.0000   -0.0121   -0.0114   -0.0108
% %     3.0000    4.0000    0.0149    0.0155    0.0162
% %     3.0000    5.0000   -0.0482   -0.0475   -0.0469
% %     4.0000    5.0000   -0.0637   -0.0631   -0.0624
% 
% 
% % 1-way ANOVA + mutlicomparison test to see whether the
% % decision rule within a non-social or social group (1 to 5) and 
% % (6 to 10) significantly influences the number of thermals visited 
% % and travel time.
% %



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Below are the functions to summarize all the SA results,%
% write it to an excel workbook, and analyse it with      %
% multiple linear regression                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function mkSummaryOutput_SA

SumOut_v7_w90_d0= ppOutputStat('simsoar_output_v7_w90_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w90_d1= ppOutputStat('simsoar_output_v7_w90_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w90_d2= ppOutputStat('simsoar_output_v7_w90_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v7_w110_d0= ppOutputStat('simsoar_output_v7_w110_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w110_d1= ppOutputStat('simsoar_output_v7_w110_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w110_d2= ppOutputStat('simsoar_output_v7_w110_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v7_w130_d0= ppOutputStat('simsoar_output_v7_w130_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w130_d1= ppOutputStat('simsoar_output_v7_w130_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w130_d2= ppOutputStat('simsoar_output_v7_w130_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v7_w150_d0= ppOutputStat('simsoar_output_v7_w150_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w150_d1= ppOutputStat('simsoar_output_v7_w150_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v7_w150_d2= ppOutputStat('simsoar_output_v7_w150_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

save('simsoar_summary_output_v7.mat','SumOut_v7_w90_d0','SumOut_v7_w90_d1','SumOut_v7_w90_d2',...
                                    'SumOut_v7_w110_d0','SumOut_v7_w110_d1','SumOut_v7_w110_d2',...
                                    'SumOut_v7_w130_d0','SumOut_v7_w130_d1','SumOut_v7_w130_d2',...
                                    'SumOut_v7_w150_d0','SumOut_v7_w150_d1','SumOut_v7_w150_d2');

clear all;

SumOut_v9_w90_d0= ppOutputStat('simsoar_output_v9_w90_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w90_d1= ppOutputStat('simsoar_output_v9_w90_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w90_d2= ppOutputStat('simsoar_output_v9_w90_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v9_w110_d0= ppOutputStat('simsoar_output_v9_w110_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w110_d1= ppOutputStat('simsoar_output_v9_w110_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w110_d2= ppOutputStat('simsoar_output_v9_w110_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v9_w130_d0= ppOutputStat('simsoar_output_v9_w130_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w130_d1= ppOutputStat('simsoar_output_v9_w130_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w130_d2= ppOutputStat('simsoar_output_v9_w130_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v9_w150_d0= ppOutputStat('simsoar_output_v9_w150_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w150_d1= ppOutputStat('simsoar_output_v9_w150_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v9_w150_d2= ppOutputStat('simsoar_output_v9_w150_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

save('simsoar_summary_output_v9.mat','SumOut_v9_w90_d0','SumOut_v9_w90_d1','SumOut_v9_w90_d2',...
                                     'SumOut_v9_w110_d0','SumOut_v9_w110_d1','SumOut_v9_w110_d2',...
                                     'SumOut_v9_w130_d0','SumOut_v9_w130_d1','SumOut_v9_w130_d2',...
                                     'SumOut_v9_w150_d0','SumOut_v9_w150_d1','SumOut_v9_w150_d2');

clear all;

SumOut_v11_w90_d0= ppOutputStat('simsoar_output_v11_w90_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w90_d1= ppOutputStat('simsoar_output_v11_w90_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w90_d2= ppOutputStat('simsoar_output_v11_w90_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v11_w110_d0= ppOutputStat('simsoar_output_v11_w110_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w110_d1= ppOutputStat('simsoar_output_v11_w110_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w110_d2= ppOutputStat('simsoar_output_v11_w110_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v11_w130_d0= ppOutputStat('simsoar_output_v11_w130_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w130_d1= ppOutputStat('simsoar_output_v11_w130_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w130_d2= ppOutputStat('simsoar_output_v11_w130_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v11_w150_d0= ppOutputStat('simsoar_output_v11_w150_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w150_d1= ppOutputStat('simsoar_output_v11_w150_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v11_w150_d2= ppOutputStat('simsoar_output_v11_w150_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

save('simsoar_summary_output_v11.mat','SumOut_v11_w90_d0','SumOut_v11_w90_d1','SumOut_v11_w90_d2',...
                                     'SumOut_v11_w110_d0','SumOut_v11_w110_d1','SumOut_v11_w110_d2',...
                                     'SumOut_v11_w130_d0','SumOut_v11_w130_d1','SumOut_v11_w130_d2',...
                                     'SumOut_v11_w150_d0','SumOut_v11_w150_d1','SumOut_v11_w150_d2');

clear all;

SumOut_v13_w90_d0= ppOutputStat('simsoar_output_v13_w90_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w90_d1= ppOutputStat('simsoar_output_v13_w90_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w90_d2= ppOutputStat('simsoar_output_v13_w90_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v13_w110_d0= ppOutputStat('simsoar_output_v13_w110_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w110_d1= ppOutputStat('simsoar_output_v13_w110_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w110_d2= ppOutputStat('simsoar_output_v13_w110_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v13_w130_d0= ppOutputStat('simsoar_output_v13_w130_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w130_d1= ppOutputStat('simsoar_output_v13_w130_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w130_d2= ppOutputStat('simsoar_output_v13_w130_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

SumOut_v13_w150_d0= ppOutputStat('simsoar_output_v13_w150_d0.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w150_d1= ppOutputStat('simsoar_output_v13_w150_d1.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});
SumOut_v13_w150_d2= ppOutputStat('simsoar_output_v13_w150_d2.mat',{'NnearT','NnearD','NdirD','NfarT','NrandT','SnearT','SnearD','SdirD','SfarT','SrandT'});

save('simsoar_summary_output_v13.mat','SumOut_v13_w90_d0','SumOut_v13_w90_d1','SumOut_v13_w90_d2',...
                                     'SumOut_v13_w110_d0','SumOut_v13_w110_d1','SumOut_v13_w110_d2',...
                                     'SumOut_v13_w130_d0','SumOut_v13_w130_d1','SumOut_v13_w130_d2',...
                                     'SumOut_v13_w150_d0','SumOut_v13_w150_d1','SumOut_v13_w150_d2');

clear all;

% calculate a summary of the summary data, for the sensitivity analysis
% data for make the arrays before writing to Excel worksheet

sum7 = mkSASummary('v7');
sum9 = mkSASummary('v9');
sum11 = mkSASummary('v11');
sum13 = mkSASummary('v13');

% make the arrays before writing to Excel worksheet

columnlbl = {'ViewRange', 'ViewAngle', 'DepartureTime', 'NnearT', 'NfarT', 'NnearD', 'NdirD', 'NrandT', 'SnearT', 'SfarT', 'SnearD', 'NdirD', 'NrandT'};

viewrange = [7*ones(12,1); 9*ones(12,1); 11*ones(12,1); 13*ones(12,1)];
viewwindow = repmat( [90 90 90 110 110 110 130 130 130 150 150 150]', 4, 1);
departuretime = repmat( [0 1 2 0 1 2 0 1 2 0 1 2]', 4, 1);

% SAsum.ttt = [ viewrange viewwindow departuretime [sum7.ttt; sum9.ttt; sum11.ttt; sum13.ttt] ];
% SAsum.tn = [ viewrange viewwindow departuretime [sum7.tn; sum9.tn; sum11.tn; sum13.tn] ];

SAsum.dt = [ viewrange viewwindow departuretime [sum7.dt; sum9.dt; sum11.dt; sum13.dt] ];
SAsum.tv = [ viewrange viewwindow departuretime [sum7.tv; sum9.tv; sum11.tv; sum13.tv] ];


% write SA-summary results to excel worksheet

disp('Writing Sensitivity analysis summaries to excel file');
xlsfilename = 'jtb_tables.xls';
sstr = fieldnames(SAsum);

xlswrite( xlsfilename,columnlbl,'SA_rdt','a1');
xlswrite( xlsfilename, SAsum.dt,'SA_rdt','a2' );
xlswrite( xlsfilename,columnlbl,'SA_tv','a1');
xlswrite( xlsfilename, SAsum.tv,'SA_tv', 'a2' );

%%

function out = mkSASummary(filelbl)

if exist('filelbl','var') 
    
infile = ['simsoar_summary_output_' filelbl '.mat'];

invar = { ['SumOut_' filelbl '_w90_d0'],...
          ['SumOut_' filelbl '_w90_d1'],...
          ['SumOut_' filelbl '_w90_d2'],...
          ['SumOut_' filelbl '_w110_d0'],...
          ['SumOut_' filelbl '_w110_d1'],...
          ['SumOut_' filelbl '_w110_d2'],...
          ['SumOut_' filelbl '_w130_d0'],...
          ['SumOut_' filelbl '_w130_d1'],...
          ['SumOut_' filelbl '_w130_d2'],...
          ['SumOut_' filelbl '_w150_d0'],...
          ['SumOut_' filelbl '_w150_d1'],...
          ['SumOut_' filelbl '_w150_d2'] };

displbl = {'w90, d0', 'w90, d1', 'w90, d2',...
           'w110, d0', 'w110, d1', 'w110, d2',...
           'w130, d0', 'w130, d1', 'w130, d2',...
           'w150, d0', 'w150, d1', 'w150, d2'};
else
    
    infile = 'simsoar_summary_output.mat';
    invar = { 'SumOut' };

end
    
nrvar = length(invar);

tttstr = cell(nrvar,1);
dtstr = cell(nrvar,1);
tvstr = cell(nrvar,1);
tnstr = cell(nrvar,1);

out=struct;
out.ttt = nan(nrvar,10);
out.dt = nan(nrvar,10);
out.tv = nan(nrvar,10);
out.tn = nan(nrvar,10);

for i = 1:nrvar

    disp(['results for ' infile  ', ' invar{i} ])
    disp(' ')
    
    load(infile,invar{i})
    
    eval(['x1 = ' invar{i} '.NnearT.tttsurv(:);'] )
    eval(['x2 = ' invar{i} '.NnearD.tttsurv(:);'] )
    eval(['x3 = ' invar{i} '.NfarT.tttsurv(:);'] )
    eval(['x4 = ' invar{i} '.NdirD.tttsurv(:);'] )
    eval(['x5 = ' invar{i} '.NrandT.tttsurv(:);'] )
    eval(['x6 = ' invar{i} '.SnearT.tttsurv(:);'] )
    eval(['x7 = ' invar{i} '.SnearD.tttsurv(:);'] )
    eval(['x8 = ' invar{i} '.SfarT.tttsurv(:);'] )
    eval(['x9 = ' invar{i} '.SdirD.tttsurv(:);'] )
    eval(['x10 = ' invar{i} '.SrandT.tttsurv(:);'] )
    
    X = [x1 x2 x3 x4 x5 x6 x7 x8 x9 x10];
   
    out.ttt(i,:) = nanmean(X)/60;  % total time traveled in minutes
    
    nrhr = floor( nanmean(X)/3600 );
    nrmin = round( 60 * ( nanmean(X)/3600 - nrhr ) );
    tstr = [];
    for j = 1:10
        tstr = [ tstr, ' ', num2str( nrhr(j) ), ':', num2str( nrmin(j) ) ];
    end
    
    tttstr{i} = [ displbl{i} ': ' tstr];
    
    %%%
    
    eval(['x1 = ' invar{i} '.NnearT.dtsurv(:);'] )
    eval(['x2 = ' invar{i} '.NnearD.dtsurv(:);'] )
    eval(['x3 = ' invar{i} '.NfarT.dtsurv(:);'] )
    eval(['x4 = ' invar{i} '.NdirD.dtsurv(:);'] )
    eval(['x5 = ' invar{i} '.NrandT.dtsurv(:);'] )
    eval(['x6 = ' invar{i} '.SnearT.dtsurv(:);'] )
    eval(['x7 = ' invar{i} '.SnearD.dtsurv(:);'] )
    eval(['x8 = ' invar{i} '.SfarT.dtsurv(:);'] )
    eval(['x9 = ' invar{i} '.SdirD.dtsurv(:);'] )
    eval(['x10 = ' invar{i} '.SrandT.dtsurv(:);'] )
    
    X = [x1 x2 x3 x4 x5 x6 x7 x8 x9 x10];

    out.dt(i,:) = nanmean(X); % relative distance traveled in km / km
    
    dtstr{i} = [ displbl{i} ': ' num2str( nanmean(X), 3 )];
    
    %%%
    
    eval(['x1 = ' invar{i} '.NnearT.tvsurv(:);'] )
    eval(['x2 = ' invar{i} '.NnearD.tvsurv(:);'] )
    eval(['x3 = ' invar{i} '.NfarT.tvsurv(:);'] )
    eval(['x4 = ' invar{i} '.NdirD.tvsurv(:);'] )
    eval(['x5 = ' invar{i} '.NrandT.tvsurv(:);'] )
    eval(['x6 = ' invar{i} '.SnearT.tvsurv(:);'] )
    eval(['x7 = ' invar{i} '.SnearD.tvsurv(:);'] )
    eval(['x8 = ' invar{i} '.SfarT.tvsurv(:);'] )
    eval(['x9 = ' invar{i} '.SdirD.tvsurv(:);'] )
    eval(['x10 = ' invar{i} '.SrandT.tvsurv(:);'] )
    
    X = [x1 x2 x3 x4 x5 x6 x7 x8 x9 x10];
    
    out.tv(i,:) = nanmean(X); % nr of thermals visited
    
    tvstr{i} = [ displbl{i} ': ' num2str( nanmean(X), 2 ) ];
    
    %%%
    
    eval(['x1 = ' invar{i} '.NnearT.tn(:);'] )
    eval(['x2 = ' invar{i} '.NnearD.tn(:);'] )
    eval(['x3 = ' invar{i} '.NfarT.tn(:);'] )
    eval(['x4 = ' invar{i} '.NdirD.tn(:);'] )
    eval(['x5 = ' invar{i} '.NrandT.tn(:);'] )
    eval(['x6 = ' invar{i} '.SnearT.tn(:);'] )
    eval(['x7 = ' invar{i} '.SnearD.tn(:);'] )
    eval(['x8 = ' invar{i} '.SfarT.tn(:);'] )
    eval(['x9 = ' invar{i} '.SdirD.tn(:);'] )
    eval(['x10 = ' invar{i} '.SrandT.tn(:);'] )
    
    X = [x1 x2 x3 x4 x5 x6 x7 x8 x9 x10];
    
    out.tn(i,:) = nanmean(X); % unique nr of thermals visited
    
    tnstr{i} = [ displbl{i} ': ' num2str( nanmean(X), 4 )];
    
end

disp('Mean time traveled (hrs:min)')
for i = 1:nrvar
    disp( ['  ', tttstr{i}] )
end

disp('Mean distance traveled (km)')
for i = 1:nrvar
    disp( ['  ', dtstr{i}] )
end

disp('Mean nr of thermals visited (nr)')
for i = 1:nrvar
    disp( ['  ', tvstr{i}] )
end

disp('Mean nr of unique thermals visited (nr)')
for i = 1:nrvar
    disp( ['  ', tnstr{i}] )
end

%%

function mkSensitivityAnalysis

rdt = xlsread('jtb_tables.xls','SA_rdt');
tv = xlsread('jtb_tables.xls','SA_tv');

% all variable combinations were tested by hand (in this script) 
% only the significant ones are kept in this script and
% written to an excel file

% parameter values for tv

X = [ones(48,1) zscore( tv(:,2) )];
[b1 i1] = regress(tv(:,4),X);
[b2 i2] = regress(tv(:,5),X);
[b3 i3] = regress(tv(:,6),X);
[b4 i4] = regress(tv(:,7),X);
[b5 i5] = regress(tv(:,8),X);

X = [ones(48,1) zscore( tv(:,1:3) )];
[b6 i6] = regress(tv(:,9),X);
[b7 i7] = regress(tv(:,10),X);
[b8 i8] = regress(tv(:,11),X);
[b9 i9] = regress(tv(:,12),X);
[b10 i10] = regress(tv(:,13),X);

C_tv = { b1(1); b2(1); b3(1); b4(1); b5(1); b6(1); b7(1); b8(1); b9(1); b10(1) };
bd_tv = { b6(2); b7(2); b8(2); b9(2); b10(2) };
va_tv = { b1(2); b2(2); b3(2); b4(2); b5(2); b6(3); b7(3); b8(3); b9(3); b10(3) };
dp_tv = { b6(4); b7(4); b8(4); b9(4); b10(4) };
Cup_rdt = { i1(1,1); i2(1,1); i3(1,1); i4(1,1); i5(1,1); i6(1,1); i7(1,1); i8(1,1); i9(1,1); i10(1,1) };
Clow_rdt = { i1(1,2); i2(1,2); i3(1,2); i4(1,2); i5(1,2); i6(1,2); i7(1,2); i8(1,2); i9(1,2); i10(1,2) };
bdup_rdt = { i6(2,1); i7(2,1); i8(2,1); i9(2,1); i10(2,1) };
bdlow_rdt = { i6(2,2); i7(2,2); i8(2,2); i9(2,2); i10(2,2) };
vaup_rdt = { i1(2,1); i2(2,1); i3(2,1); i4(2,1); i5(2,1); i6(3,1); i7(3,1); i8(3,1); i9(3,1); i10(3,1) };
valow_rdt = { i1(2,2); i2(2,2); i3(2,2); i4(2,2); i5(2,2); i6(3,2); i7(3,2); i8(3,2); i9(3,2); i10(3,2) };
dpup_rdt = { i6(4,1); i7(4,1); i8(4,1); i9(4,1); i10(4,1) };
dplow_rdt = { i6(4,2); i7(4,2); i8(4,2); i9(4,2); i10(4,2) };

% calculation of standard errors

se1 = [i1(:,2)-i1(:,1)]/3.92;
se2 = [i2(:,2)-i2(:,1)]/3.92;
se3 = [i3(:,2)-i3(:,1)]/3.92;
se4 = [i4(:,2)-i4(:,1)]/3.92;
se5 = [i5(:,2)-i5(:,1)]/3.92;
se6 = [i6(:,2)-i6(:,1)]/3.92;
se7 = [i7(:,2)-i7(:,1)]/3.92;
se8 = [i8(:,2)-i8(:,1)]/3.92;
se9 = [i9(:,2)-i9(:,1)]/3.92;
se10 = [i10(:,2)-i10(:,1)]/3.92;


% parameter values for rdt

X = [ones(48,1) zscore( rdt(:,2) )];
[b1 i1] = regress(rdt(:,4),X);
[b2 i2] = regress(rdt(:,5),X);
[b3 i3] = regress(rdt(:,6),X);
[b4 i4] = regress(rdt(:,7),X);
[b5 i5] = regress(rdt(:,8),X);
[b6 i6] = regress(rdt(:,9),X);
[b7 i7] = regress(rdt(:,10),X);
[b8 i8] = regress(rdt(:,11),X);
[b9 i9] = regress(rdt(:,12),X);
[b10 i10] = regress(rdt(:,13),X);

C_rdt = { b1(1); b2(1); b3(1); b4(1); b5(1); b6(1); b7(1); b8(1); b9(1); b10(1) };
va_rdt = { b1(2); b2(2); b3(2); b4(2); b5(2); b6(2); b7(2); b8(2); b9(2); b10(2) };
Cup_rdt = { i1(1,1); i2(1,1); i3(1,1); i4(1,1); i5(1,1); i6(1,1); i7(1,1); i8(1,1); i9(1,1); i10(1,1) };
Clow_rdt = { i1(1,2); i2(1,2); i3(1,2); i4(1,2); i5(1,2); i6(1,2); i7(1,2); i8(1,2); i9(1,2); i10(1,2) };
vaup_rdt = { i1(2,1); i2(2,1); i3(2,1); i4(2,1); i5(2,1); i6(2,1); i7(2,1); i8(2,1); i9(2,1); i10(2,1) };
valow_rdt = { i1(2,2); i2(2,2); i3(2,2); i4(2,2); i5(2,2); i6(2,2); i7(2,2); i8(2,2); i9(2,2); i10(2,2) };

% calculation of standard errors

se1 = [i1(:,2)-i1(:,1)]/3.92;
se2 = [i2(:,2)-i2(:,1)]/3.92;
se3 = [i3(:,2)-i3(:,1)]/3.92;
se4 = [i4(:,2)-i4(:,1)]/3.92;
se5 = [i5(:,2)-i5(:,1)]/3.92;
se6 = [i6(:,2)-i6(:,1)]/3.92;
se7 = [i7(:,2)-i7(:,1)]/3.92;
se8 = [i8(:,2)-i8(:,1)]/3.92;
se9 = [i9(:,2)-i9(:,1)]/3.92;
se10 = [i10(:,2)-i10(:,1)]/3.92;

xlswrite( 'jtb_tables.xls',C_tv,'Table7','b6');
xlswrite( 'jtb_tables.xls',bd_tv,'Table7','c11');
xlswrite( 'jtb_tables.xls',va_tv,'Table7','d6');
xlswrite( 'jtb_tables.xls',dp_tv,'Table7','e11');

xlswrite( 'jtb_tables.xls',C_rdt,'Table7','b19');
xlswrite( 'jtb_tables.xls',va_rdt,'Table7','d19');

%%

function out = ppOutputStat(filename,runnames,selected_thermalfields)
%
% out = ppOutputStat('filename','bird-outputarray',selected_thermalfields)
%  
% out contains the following fields:
%
%   surv = survival of each bird per thermalfield
%
%   asr = succes ratio, averaged over birds and thermal fields
%   asrb = succes ratio per bird, averaged over thermal fields 
%   asrt = succes ratio per thermal field, averaged over birds 
%   hsrb = histogram of succes ratio, based on data from asrb
%   hsrt = histogram of succes ratio, based on data from asrt
%   bsr = bins of succes ratio histograms
%
%   esall = raw data of effective speed, for all birds
%   esdead = raw data of effective speed, only the birds that did not make 
%               it to the destination
%   essurv = raw data of effective speed, only the birds that did make it
%               it to the destination
%   dtall = raw data of distance traveled, for all birds
%   dtdead = raw data of distance traveled, only the birds that did not make 
%               it to the destination
%   dtsurv = raw data of distance traveled, only the birds that did make it
%               it to the destination
%   tvall =  etc.
%   tvdead = ..
%   tvsurv = ..
%   trall = ..
%   trdead = ..
%   trsurv = ..
%
%  And the following fields of 'out' are calculated for the surving birds
%  only:
% 
%   aes = effective flightspeed, averaged over birds and thermal fields
%   adt = distance traveled, averaged over birds and thermal fields
%   atv = number of thermals visited, averaged over birds and
%           thermal fields
%   atr = ratio time spent in thermal/time spent in travel, averaged over
%           birds and thermal fields
%
%   aesb = effective flightspeed per bird, averaged over thermal fields 
%   adtb = distance traveled per bird, averaged over thermal fields 
%   atvb = number of thermals visited per bird, averaged over thermal fields 
%   atrb = ratio time spent in thermal/time spent in travel per bird, 
%           averaged over thermal fields 
%
%   aest = effective flightspeed per thermal field, averaged over birds 
%   adtt = distance traveled per thermal field, averaged over birds 
%   atvt = number of thermals visited per thermal field, averaged over birds 
%   atrt = ratio time spent in thermal/time spent in travel per thermal field, 
%           averaged over birds
%
%   hest = histogram effective flightspeed
%   hdtt = histogram distance traveled
%   htvt = histogram thermals visited
%   htrt = histogram thermaltime/traveltime ratio
%   ..
%   hsrb = histogram of succes ratio, averages over thermal fields
%   hesb = etc.
%   ..
%   hsr = histogram of succes ratio, using raw data
%   hes = etc.
%   ..
%   bsr = bins of succes ratio histograms
%   bes = etc.
%
% 
% the input argument 'selected_runnrs' is optional
%
% e.g.
%
% out = ppOutputStat('simsoar_output.mat',{'NnearT'});
%   or
% out = ppOutputStat('simsoar_output.mat',{'NnearT', 'NfarT', 'NfarD', 'SnearT', 'SfarT', 'SfarD'})


warning('off', 'MATLAB:load:variableNotFound');
load(filename, 'thermalfields')
warning('on', 'MATLAB:load:variableNotFound');

if nargin==3
    runnrs = intersect(thermalfields, selected_thermalfields);
    if isempty(thermalfields)
        disp('The selected run numbers (third input argument) are not present in the data set')
    end
end


if ~iscell(runnames)
    runnames = {runnames};
end

for h = 1:length(runnames)

    runname = runnames{h};
   
    surv = [];
    dtd = [];
    tdt =[];
    tv = [];
    tr = [];
    ttt = [];
    tn = [];
    
    nrthermalfield = length(thermalfields); 
    ut = cell(nrthermalfield,1);  % empty cell array to store used thermals
    
    for i = 1 : nrthermalfield

        runnamenr = [ runname num2str( thermalfields(i) ) ];
        disp([' Now processing: ' runnamenr ]);
        load(filename,runnamenr);
        
        % this if statement is put here to deal with the two different
        % ways by which the output is stored currently via Amoves --
        % has to be updated so that only one way remains.
        eval([ 'birdoutput = ' runnamenr ';']);
        clear(runnamenr);

        % onGround = birdoutput.onGround;
        atDest = birdoutput.atDestination;
        nrbird = length(atDest);
        surv = [surv, atDest];

        % calculate nr of thermals visited - to correct a.o. for the
        % instantaneous 200m displacement
        tvtemp = nan( nrbird, 1 );
        uttemp = [];
        whichtherm = birdoutput.whichThermal;
        % whichtherm = whichtherm(atdest,:);
        for j = 1:nrbird
            uniquetherm = unique( whichtherm(j,:) );
            uniquetherm = uniquetherm ( uniquetherm~=0 );
            tvtemp(j) = length( uniquetherm );
            uttemp = [ uttemp; uniquetherm(:) ]; 
        end
        tv = [tv, tvtemp];
        ut{i} = unique(uttemp);        % unique thermals
        tn = [tn, length( ut{i} )];    % number of unique thermals visited in one themal field!
        
        dtdtemp = sqrt ( ( birdoutput.iDestX - birdoutput.X(:,1) ).^2 + ...
                ( birdoutput.iDestY - birdoutput.Y(1) ).^2 );

        dtd = [ dtd, dtdtemp ];
        ttt = [ ttt, birdoutput.FlightTime + birdoutput.TimeLost ];

        Xl = birdoutput.X ;
        Yl = birdoutput.Y ;
        tdttemp = nansum ( sqrt ( (Xl(:,2:end) - Xl(:,1:end-1)).^2 + (Yl(:,2:end) - Yl(:,1:end-1)).^2 ), 2) ;

        tdt = [ tdt, tdttemp ];

    end

    es = dtd./ttt;
    rdt = tdt./dtd;
    
    %%%%
    % storing & calculating histograms for
    % survival (surv) and survival ratio (sr)
    %%%%

    asr = sum(surv(:))/(nrbird*nrthermalfield);
    asrb = sum(surv,2)/nrthermalfield;
    asrt = sum(surv,1)/nrbird;    
    try
        bsr = linspace(min( [asrb(:); asrt(:)] ),max( [asrb(:); asrt(:)] ),11);
    catch
        bsr = zeros(1,11);
    end
    
    runoutput.surv = surv;
    runoutput.asr = asr;
    runoutput.asrb = asrb;
    runoutput.asrt = asrt;
    runoutput.bsr = bsr;
    runoutput.hsrb = histc(asrb,bsr);
    runoutput.hsrt = histc(asrt,bsr);

    % note: all the other statistics are only calculated
    % for those birds that make it to the end
    % In this way the length, of the simulation period
    % for all these birds is the same and in a way also
    % the thermal field is comparable (they all traverse
    % it from start to destination).
    % Later this may be extended to also consider the statistics
    % of the birds that do not make it to the end. The values are 
    % already separated for the survivors (..surv) and the non-
    % survivors (..dead).
    
    % mean --> nanmean to deal with NaN's,
    % min & max deal properly with NaN's, so for these functions
    % nothing special is required
    
    %%%%
    % storing & calculating histograms for
    % effective speed (es)
    %%%%

    esall = es;
    esdead = es; 
    esdead ( surv == 1 ) = NaN;
    es( surv == 0 ) = NaN; 
    
    aes = nanmean(es(:));
    aesb = nanmean(es,2);
    aest = nanmean(es,1);
     
    try
        bes = linspace(min(es(:)),max(es(:)),11);
    catch
        bes = zeros(1,11);
    end
    runoutput.esall = esall;
    runoutput.esdead = esdead;
    runoutput.essurv = es;
    runoutput.aes = aes;
    runoutput.aesb = aesb;
    runoutput.aest = aest;
    runoutput.bes = bes;
    runoutput.hes = histc(es,bes);
    runoutput.hesb = histc(aesb,bes);
    runoutput.hest = histc(aest,bes);

    %%%%
    % storing & calculating histograms for
    % relative distance traveled (rdt)
    %%%%
    
    rdtall = rdt;
    rdtdead = rdt; 
    rdtdead ( surv == 1 ) = NaN;
    rdt( surv == 0 ) = NaN;
    
    adt = nanmean(rdt(:));
    adtb = nanmean(rdt,2);
    adtt = nanmean(rdt,1);
    try
        bdt = linspace(min(rdt(:)),max(rdt(:)),11);
    catch
        bdt = zeros(1,11);
    end
    runoutput.dtall = rdtall;
    runoutput.dtdead = rdtdead;
    runoutput.dtsurv = rdt;
    
    runoutput.adt = adt;
    runoutput.adtb = adtb;
    runoutput.adtt = adtt;
    runoutput.bdt = bdt;
    runoutput.hdt = histc(rdt,bdt);
    runoutput.hdtb = histc(adtb,bdt);
    runoutput.hdtt = histc(adtt,bdt);

    %%%%
    % storing & calculating histograms for
    % nr of thermals vistited (tv)
    %%%%
    
    tvall = tv;
    tvdead = tv; 
    tvdead ( surv == 1 ) = NaN;
    tv( surv == 0 ) = NaN; 
    
    atv = nanmean(tv(:));
    atvb = nanmean(tv,2);
    atvt = nanmean(tv,1);
    nrbin = min( 11 , max(tv)-min(tv)+2 );
    try
        btv = linspace(min(tv)-0.5 , max(tv)+0.5 , nrbin );  % the 0.5 thing is done because tv comprises only integers
    catch
        btv = zeros(1,11);
    end
    runoutput.tvall = tvall;
    runoutput.tvdead = tvdead;
    runoutput.tvsurv = tv;
    runoutput.atv = atv;
    runoutput.atvb = atvb;
    runoutput.atvt = atvt;
    runoutput.btv = btv;
    runoutput.htv = histc(tv,btv);
    runoutput.htvb = histc(atvb,btv);
    runoutput.htvt = histc(atvt,btv);

    %%%%
    % storing & calculating histograms for
    % travel ratio (time climbing / time gliding) (tr)
    %%%%

    tr( surv == 0 ) = NaN; 
    
    atr = nanmean(tr(:));
    atrb = nanmean(tr,2);
    atrt = nanmean(tr,1);
    try
        btr = linspace(min(tr(:)),max(tr(:)),11);
    catch
        btr = zeros(1,11);
    end
    runoutput.tr = tr;
    runoutput.atr = atr;
    runoutput.atrb = atrb;
    runoutput.atrt = atrt;
    runoutput.btr = btr;
    runoutput.htr = histc(tr,btr);
    runoutput.htrb = histc(atrb,btr);
    runoutput.htrt = histc(atrt,btr);

    %%%%
    % storing results for distance to destination
    %%%%
    
    dtdall = dtd;
    dtddead = dtd; 
    dtddead(surv == 1) = NaN;
    dtd( surv == 0 ) = NaN; 
    
    adtd = nanmean(dtd(:));
    adtdb = nanmean(dtd,2);
    adtdt = nanmean(dtd,1);

    runoutput.dtdall = dtdall;
    runoutput.dtddead = dtddead;
    runoutput.dtdsurv = dtd;
    runoutput.adtd = adtd;
    runoutput.adtdb = adtdb;
    runoutput.adtdt = adtdt;

    %%%%
    % storing results for total distance traveled
    %%%%

    tdtall = tdt;
    tdtdead = tdt; 
    tdtdead(surv == 1) = NaN;
    tdt( surv == 0 ) = NaN; 
    
    atdt = nanmean(tdt(:));
    atdtb = nanmean(tdt,2);
    atdtt = nanmean(tdt,1);

    runoutput.tdtall = tdtall;
    runoutput.tdtdead = tdtdead;
    runoutput.tdtsurv = tdt;
    runoutput.atdt =  atdt;
    runoutput.atdtb = atdtb;
    runoutput.atdtt = atdtt;

    %%%%
    % storing results for total time travelled
    %%%%

    tttall = ttt;
    tttdead = ttt; 
    tttdead(surv == 1) = NaN;
    ttt( surv == 0 ) = NaN; 
    
    attt = nanmean(ttt(:));
    atttb = nanmean(ttt,2);
    atttt = nanmean(ttt,1);

    runoutput.tttall = tttall;
    runoutput.tttdead = tttdead;
    runoutput.tttsurv = ttt;
    runoutput.attt =  attt;
    runoutput.atttb = atttb;
    runoutput.atttt = atttt;

    %%%%
    % storing results for unique thermals visited 
    % and unique number of thermals visited
    %%%%

    runoutput.ut = ut;
    runoutput.tn = tn;
    runoutput.atn = nanmean(tn(:));
    
    eval( ['out.' runname ' = runoutput;'] )
    
end
